
# ::file::Exit
#
#    Prompt for confirmation then exit.
#
proc ::file::Exit {}  {
  # Check for altered game in all bases except the clipbase:
  set unsavedCount 0
  set savedBase [sc_base current]
  set msg ""
  set nbases [sc_base count total]
  for {set i 1} {$i < [sc_base count total]} {incr i} {
    sc_base switch $i
    if {[sc_base inUse] && [sc_game altered] && ![sc_base isReadOnly]} {
      if {$unsavedCount == 0} {
        append msg $::tr(ExitUnsaved)
        append msg "\n\n"
      }
      incr unsavedCount
      set fname [file tail [sc_base filename]]
      set g [sc_game number]
      append msg "   Base $i: $fname "
      append msg "($::tr(game) $g)"
      append msg "\n"
    }
  }
  # Switch back to original database:
  sc_base switch $savedBase

  if {$msg != ""} {
    append msg "\n"
  }
  append msg $::tr(ExitDialog)

  # Only ask before exiting if there are unsaved changes:
  if {$unsavedCount > 0} {
    set answer [tk_messageBox -title "ChessDB: [tr FileExit]" \
                  -message $msg -type yesno -icon question]
    if {$answer != "yes"} { return }
  }
  # if {$::optionsAutoSave} { .menu.options invoke [tr OptionsSave] }
  puts "optionsAutosave=$::optionsAutoSave"
  if {$::optionsAutoSave} { 
    SaveAllOptions
    puts "saving all ipitons"
  }
  ::recentFiles::save
  ::utils::history::Save
  destroy .
}

proc ::file::ExitFast {} {
  if {$::optionsAutoSave} { .menu.options invoke [tr OptionsSave] }
  ::recentFiles::save
  destroy .
}

# ::file::New
#
#   Opens file-save dialog and creates a new database.
#
proc ::file::New {} {
  if {[sc_base count free] == 0} {
    tk_messageBox -title "ChessDB" -type ok -icon info \
      -message [ tr TooManyDatabasesOpen ]
    return
  }
  set ftype {
    { "ChessDB databases, EPD files" {".si3" ".epd"} }
    { "ChessDB databases" {".si3"} }
    { "EPD files" {".epd"} }
  }
  set fName [tk_getSaveFile -initialdir $::initialDir(base) -filetypes $ftype -title [ tr CreateChessDBDatabase ] ]
  if {$fName == ""} {
    # do nothing
  } elseif {[file extension $fName] == ".epd"} {
    newEpdWin create $fName
    return
  } else {
    set fName [file rootname $fName]
    if {[catch {sc_base create $fName} result]} {
      tk_messageBox -icon warning -type ok -parent . \
        -title [tr TitleUnableToCreateBase] -message $result
    }
  }
  ::windows::gamelist::Refresh
  ::tree::refresh
  updateMenuStates
  updateTitle
  updateStatusBar
}

# ::file::Open
#
#    Opens file-open dialog and opens the selected ChessDB database.
#
proc ::file::Open {{fName ""}} {
  global glstart
  if {[sc_base count free] == 0} {
    tk_messageBox -type ok -icon info -title "ChessDB" \
      -message [ tr TooManyDatabasesOpen ]
    return
  }

  if {[sc_info gzip]} {
    set ftype {
      { "All ChessDB files" {".si3" ".si" ".pgn" ".pgn.gz" ".epd" ".epd.gz" ".sor"} }
      { "ChessDB databases, PGN files" {".si3" ".si" ".pgn" ".PGN" ".pgn.gz"} }
      { "ChessDB databases" {".si3" ".si"} }
      { "PGN files" {".pgn" ".PGN" ".pgn.gz"} }
      { "EPD files" {".epd" ".EPD" ".epd.gz"} }
      { "Repertoire files" {".sor"} }
    }
  } else {
    set ftype {
      { "All ChessDB files" {".si3" ".si" ".pgn" ".epd" ".sor"} }
      { "ChessDB databases, PGN files" {".si3" ".si" ".pgn" ".PGN"} }
      { "ChessDB databases]" {".si3" ".si"} }
      { "PGN files" {".pgn" ".PGN"} }
      { "EPD files" {".epd" ".EPD"} }
      { "Repertoire files" {".sor"} }
    }
  }
  if {$fName == ""} {
    set fName [tk_getOpenFile -initialdir $::initialDir(base) -filetypes $ftype -title [ tr OpenAChessDBFile ] ]
    if {$fName == ""} { return }
  }

  if {[file extension $fName] == ""} {
    set fName "$fName.si3"
  }

  if {[file extension $fName] == ".sor"} {
    if {[catch {::rep::OpenWithFile $fName} err]} {
      tk_messageBox -parent . -type ok -icon info -title "ChessDB" \
        -message "[tr ErrorReadingSearchOptionsFile] \"$fName\": $err"
    }
    return
  }

  if {[file extension $fName] == ".si"} {
    ::file::Upgrade [file rootname $fName]
    return
  }

  set err 0
  busyCursor .
  if {[file extension $fName] == ".si3"} {
    set fName [file rootname $fName]
    if {[catch {openBase $fName} result]} {
      set err 1
      tk_messageBox -icon warning -type ok -parent . \
        -title [ tr ErrorOpeningFile ]  -message "$result $fName \n\n[tr YouAreAdvisedToClose]\n\n[tr IfYouCantResolveError]"
    } else {
      set ::initialDir(base) [file dirname $fName]
      ::recentFiles::add "$fName.si3"
    }
  } elseif {[string match "*.epd" [string tolower $fName]]} {
    # EPD file:
    newEpdWin open $fName
  } else {
    # PGN file:
    set result [tr ThisFileIsNotReadable] 
    if {(![file readable $fName])  || \
          [catch {sc_base create $fName true} result]} {
      set err 1
      tk_messageBox -icon warning -type ok -parent . \
        -title  [ tr ErrorOpeningFile ]  -message "$result $fName"
    } else {
      doPgnFileImport $fName "[ tr Opening] [file tail $fName] [ tr ReadOnly]\n"
      sc_base type [sc_base current] 3
      ::recentFiles::add $fName
    }
  }

  if {$err == 0} {
    catch {sc_game load auto}
    flipBoardForPlayerNames $::myPlayerNames
  }
  unbusyCursor .
  set glstart 1
  ::windows::gamelist::Refresh
  ::tree::refresh
  ::windows::stats::Refresh
  updateMenuStates
  updateBoard -pgn
  updateTitle
  updateStatusBar
}

# ::file::Upgrade
#
#   Upgrades an old (version 2) Scid database to ChessDB version 3.
#
proc ::file::Upgrade {name} {
  if {[file readable "$name.si3"]} {
    set msg [string trim $::tr(ConfirmOpenNew)]
    set res [tk_messageBox -title "ChessDB" -type yesno -icon info -message $msg]
    if {$res == "no"} { return }
    ::file::Open "$name.si3"
    return
  }

  set msg [string trim $::tr(ConfirmUpgrade)]
  set res [tk_messageBox -title "ChessDB" -type yesno -icon info -message $msg]
  if {$res == "no"} { return }
  progressWindow "ChessDB" "$::tr(Upgrading): [file tail $name]..."\
    $::tr(Cancel) "sc_progressBar"
  busyCursor .
  update
  set err [catch {sc_base upgrade $name} res]
  unbusyCursor .
  closeProgressWindow
  if {$err} {
    tk_messageBox -title "ChessDB" -type ok -icon warning \
      -message "[tr UnableToUpgradeTheDatabase]:\n$res"
    return
  }
  ::file::Open "$name.si3"
}

# openBase:
#    Opens a ChessDB database, showing a progress bar in a separate window
#    if the database is around 1 Mb or larger in size.
#
proc openBase {name} {
  set bsize 0
  set gfile "[file rootname $name].sg3"
  if {! [catch {file size $gfile} err]} { set bsize $err }
  set showProgress 0
  if {$bsize > 1000000} { set showProgress 1 }
  if {$showProgress} {
    progressWindow "ChessDB" "$::tr(OpeningTheDatabase): [file tail $name]..."
  }
  set err [catch {sc_base open $name} result]
  if {$showProgress} { closeProgressWindow }
  if {$err} { return -code error $result }
  return $result
}


# ::file::Close:
#   Closes the active base.
#
proc ::file::Close {{base -1}} {
  # Remember the current base:
  set current [sc_base current]
  if {$base < 0} { set base $current] }

  # Switch to the base which will be closed, and check for changes:
  sc_base switch $base
  if {[sc_base inUse]} {
    if {![::game::ConfirmDiscard]} {
      sc_base switch $current
      return
    }
    sc_base close
    # Now switch back to the original base
    sc_base switch $current

    ::windows::gamelist::Refresh
    # Close Tree and Email windows whenever a base is closed/switched:
    #if {[winfo exists .treeWin]} { destroy .treeWin }
    if {[winfo exists .emailWin]} { destroy .emailWin }
    ::pgn::Refresh
    updateBoard
  }
  updateMenuStates
  updateStatusBar
  updateTitle
}


proc ::file::SwitchToBase {b} {
  sc_base switch $b
  # Close email window when a base is switched:
  if {[winfo exists .emailWin]} { destroy .emailWin }
  updateBoard -pgn
  updateTitle
  updateMenuStates
  updateStatusBar
  ::windows::gamelist::Refresh
}

proc ::file::Save {} {
    tk_messageBox -title [tr SaveDatabase] -type ok -icon info \
      -message "[ tr DatabaseAreAlwaysSaved1 ]\n\n[ tr DatabaseAreAlwaysSaved2 ]\n\n[ tr DatabaseAreAlwaysSaved3]"
}

proc ::file::Backup {} {

    # Print a message if the user tries to back up the clipbase. This explains how he/she can move
    # the games to another database if they really want to back them up. 
    if {[sc_base current] == [sc_info clipbase]} {
       tk_messageBox -title [tr TitleBackupClipbase]  -type ok -icon warning -message "[tr BackupClipbase1]\n\n[tr BackupClipbase2]"
       return
    }
    # Find the number of games in the database and other useful info.
    set NumberOfGames [sc_base numGames]
    set basefilename [sc_base filename]
    set basefilename [ file nativename $basefilename]
    set appenddata [clock format [clock seconds] -format {_%Y-%m-%d_%H:%M}]
    set justname [file tail $basefilename ]
    
    # If there are no games in the database, then there is no point backing it up! 
    if { $NumberOfGames == 0 } {
      tk_messageBox -title "[tr TitleNoGamesInDatabase] `$justname`" -type ok -icon warning  -message [tr NoGamesInDatabase]
      return
    }

    # At this point, we can assume the database is open, has 1 or more games in it, and so can be backed up. 
    # The data and time get appended to such a database.

    tk_messageBox -title "[tr BackupDatabase] `$justname`" -type okcancel -icon info \
      -message "[ tr BackupDatabaseNow ] $NumberOfGames [tr BackupDatabaseNow1]$justname$appenddata\n\n[tr BackupDatabaseNow4]\n\n[tr BackupDatabaseNow5]"

    set BackupDirname [tk_chooseDirectory -title "[tr TitleChooseDirectoryForBackup] '$justname$appenddata'" ]
   if { $BackupDirname == "" } {return}
    
   set indexext .si3
   set nameext .sn3
   set gameext .sg3

   set src1 [ file join $basefilename$gameext]
   set src2 [ file join $basefilename$indexext]
   set src3 [ file join $basefilename$nameext]

   # Get the native names, as these might be printed and it is less confusing to users. 
   set src1 [ file nativename $src1]
   set src2 [ file nativename $src2]
   set src3 [ file nativename $src3]

   puts $src1
   puts $src2
   puts $src3
   set length1 [file size $src1]
   set length2 [file size $src2]
   set length3 [file size $src3]

   set dest1 [file join  $BackupDirname $justname$appenddata$gameext]
   set dest2 [file join  $BackupDirname $justname$appenddata$indexext]
   set dest3 [file join  $BackupDirname $justname$appenddata$nameext]

   set dest1 [ file nativename $dest1]
   set dest2 [ file nativename $dest2]
   set dest3 [ file nativename $dest3]
  
   puts $dest1
   puts $dest2
   puts $dest3

  #file copy 
  # Remember the current base:
  set current [sc_base current]
  # Switch to the base which will be closed, and check for changes:
  if {[sc_base inUse]} {
    if {![::game::ConfirmDiscard]} {
      sc_base switch $current
      return
    }
    sc_base close

    ::windows::gamelist::Refresh
    # Close Tree and Email windows whenever a base is closed/switched:
    #if {[winfo exists .treeWin]} { destroy .treeWin }
    if {[winfo exists .emailWin]} { destroy .emailWin }
    ::pgn::Refresh
    updateBoard
    if {[catch {file copy $src1 $dest1} err]} {
       tk_messageBox -title [tr TitleErrorCopyingFile] -type ok -icon error -message "$err\n\n[tr NotBackedUpProperly]"
       return
     }
    if {[catch {file copy $src2 $dest2} err]} {
       tk_messageBox -title [tr TitleErrorCopyingFile] -type ok -icon error -message "$err\n\n[tr NotBackedUpProperly]"
       return
     }
    if {[catch {file copy $src3 $dest3} err]} {
       tk_messageBox -title [tr TitleErrorCopyingFile] -type ok -icon error -message "$err\n\n[tr NotBackedUpProperly]"
       return
     }
  }
  set newname [file nativename [ file join $BackupDirname $justname$appenddata ] ] 
  set totalsize [ expr {($length1 + $length2 + $length3)}]
  # Print the size of the backup (all 3 files) in either bytes, kB or MB. Round kB and Mb to 2 significant figures. 
  if { $totalsize < 1024 } {
     tk_messageBox -title [tr TitleBackupOK] -type ok -icon info -message "[tr BackupOK]\n\n\n\n[tr OriginalDatabase] $basefilename\n\n[tr Backup] $newname\n\n[tr NumOfGames] $NumberOfGames\n\n[tr Sizeb] $totalsize]"
     return
  } elseif {$totalsize > 1048576} {
    set totalsize [ expr {($length1 + $length2 + $length3)/1048576.0}]
    tk_messageBox -title [tr TitleBackupOK] -type ok -icon info -message "[tr BackupOK]\n\n\n\n[tr OriginalDatabase] $basefilename\n\n[tr Backup] $newname\n\n[tr NumOfGames] $NumberOfGames\n\n[tr SizeMb] [format "%.2f" $totalsize]"
  } else {
    set totalsize [ expr {($length1 + $length2 + $length3)/1024.0}]
    tk_messageBox -title [tr TitleBackupOK] -type ok -icon info -message "[tr BackupOK]\n\n\n\n[tr OriginalDatabase] $basefilename\n\n[tr Backup] $newname\n\n[tr NumOfGames] $NumberOfGames\n\n[tr Sizekb] [format "%.2f" $totalsize]"
  }
}


