# romanium-basic.tcl:
# Text for menu names and status bar help messages in English.
# Part of ChessDB which is a fork of Scid (Shane's Chess Information Database).
#
# Instructions for adding a new language:
#
# (1) Choose a letter code for the language. Currently assigned codes are:
#      E=English, D=Deutsch, F=Francais, S=Spanish, B=Brasil Portuguese,
#      P=Polish, N=Nederlands, W=Swedish, O=Norsk, C=Czech, H=Hungarian,
#      Y=Serbian K=Korean Q=Romanium
#
# (2) Edit the code below that has the lines "addLanguage ..." and add your
#     new language. The final digit in each line is the index of the
#     letter to underline in the menu, counting from 0 as the first letter.
#
# (3) Copy the section of English menu and help message details below (all
#     the commands that start "menuText E ..." or "helpMsg E ..." or
#     "translate E ...") and change all the "E" letters to the letter you
#     assigned for the new language.
#
# (4) Write the translations. This involves changing anything "in quotes"
#     or {in braces} for the menuText, helpMsg and translate commands.
#
#     A menu command has the format:
#         menuText L tag "Name..." underline {HelpMessage...}
#
#     A status bar help message for a button has the format:
#         helpMsg L tag {HelpMessage...}
#
#     A general word or message translation has the format:
#         translate L tag {message...}
#
#     where "L" is the language letter, "tag" is the name of the menu entry
#     or the button widget name, and "underline" is the index of the letter
#     to underline, counting from zero as the first letter. Two menu entries
#     that appear in the same menu should have a different underlined letter.
#     If in doubt, just make them all "0" and I'll assign sensible underlined
#     letters when your translations are incorporated into ChessDB.
#
# Additions, corrections? Email: drkirkby@users.sourceforge.net


addLanguage Q Romanium iso8859-16

proc setLanguage_Q {} {

menuText Q File "File" 0
menuText Q FileNew "New..." 0 {Create a new ChessDB database or EPD (Extended Position Description) file}
menuText Q FileOpen "Open..." 0 {Open an existing ChessDB database}
menuText Q FileClose "Close database" 0 {Close the active ChessDB database}
menuText Q FileSave "Save database" 0 {Message about saving database}
menuText Q FileBackup "Backup database" 0 {Backup the current database, appending present date/time to name}
menuText Q FileCopy "Copy database" 5 {Copy the current database, to any name or location you want}
menuText Q FileFinder "Finder" 0 {Open the File Finder window}
menuText Q FileBookmarks "Bookmarks" 0 {Bookmarks menu (shortcut: Ctrl+B)}
menuText Q FileBookmarksAdd "Add Bookmark" 0  {Bookmark the current database game and position}
menuText Q FileBookmarksFile "File Bookmark" 0  {File a bookmark for the current game and position}
menuText Q FileBookmarksEdit "Edit Bookmarks..." 0  {Edit the bookmarks menus}
menuText Q FileBookmarksList "Display Folders as Single List" 0  {Display bookmark folders as a single list, not submenus}
menuText Q FileBookmarksSub "Display Folders as Submenus" 0  {Display bookmark folders as submenus, not a single list}
menuText Q FileMaint "Maintenance" 0 {ChessDB database maintenance tools}
menuText Q FileMaintBackup "Backup database" 0 {Backup the current database, appending present date/time to name}
menuText Q FileMaintWin "Maintenance Window" 0  {Open/close the ChessDB database maintenance window}
menuText Q FileMaintCompact "Compact Database..." 0  {Compact database files, removing deleted games and unused names}
menuText Q FileMaintClass "ECO-Classify Games..." 2 {Recompute the ECO code of all games}
menuText Q FileMaintSort "Sort Database..." 0  {Sort all games in the database}
menuText Q FileMaintDelete "Delete Twin Games..." 0  {Find twin games and set them to be deleted}
menuText Q FileMaintTwin "Twin Checker Window" 0  {Open/update the Twin checker window}
menuText Q FileMaintName "Name Spelling" 0 {Name editing and spelling tools}
menuText Q FileMaintNameEditor "Name Editor" 0  {Open/close the name editor window}
menuText Q FileMaintNamePlayer "Spellcheck Player Names..." 11  {Spellcheck player names using the spellcheck file}
menuText Q FileMaintNameEvent "Spellcheck Event Names..." 11  {Spellcheck event names using the spellcheck file}
menuText Q FileMaintNameSite "Spellcheck Site Names..." 11  {Spellcheck site names using the spellcheck file}
menuText Q FileMaintNameRound "Spellcheck Round Names..." 11  {Spellcheck round names using the spellcheck file}
menuText Q FileReadOnly "Read-only..." 0  {Treat the current database as read-only, preventing changes}
menuText Q FileSwitch "Switch to Database" 0  {Switch to a different opened database}
menuText Q FileExit "Exit" 1 {Exit ChessDB}
menuText Q Edit "Edit" 0
menuText Q EditAdd "Add Variation" 0 {Add a variation at this move in the game}
menuText Q EditDelete "Delete Variation" 0 {Delete a variation for this move}
menuText Q EditFirst "Make First Variation" 5  {Promote a variation to be first in the list}
menuText Q EditMain "Promote Variation to Main Line" 21  {Promote a variation to be the main line}
menuText Q EditTrial "Try Variation" 0  {Start/stop trial mode, for testing an idea on the board}
menuText Q EditStrip "Strip" 2 {Strip comments or variations from this game}
menuText Q EditStripComments "Comments" 0  {Strip all comments and annotations from this game}
menuText Q EditStripVars "Variations" 0 {Strip all variations from this game}
menuText Q EditStripBegin "Moves from the beginning" 1  {Strip moves from the beginning of the game}
menuText Q EditStripEnd "Moves to the end" 0  {Strip moves to the end of the game}
menuText Q EditReset "Empty Clipbase" 0  {Reset the clipbase to be completely empty}
menuText Q EditCopy "Copy This Game to Clipbase" 0  {Copy this game to the Clipbase database}
menuText Q EditPaste "Paste Last Clipbase Game" 0  {Paste the active Clipbase game here}
menuText Q EditPastePGN "Paste Clipboard text as PGN game..." 18  {Interpret the clipboard text as a game in PGN notation and paste it here}
menuText Q EditSetup "Setup Start Board..." 0  {Set the start position for this game}
menuText Q EditCopyBoard "Copy Position" 6 {Copy the current board in FEN notation to the text selection (clipboard)}
menuText Q EditPasteBoard "Paste Start Board" 12  {Set the start board from the current text selection (clipboard)}
menuText Q Game "Game" 0
menuText Q GameNew "New Game" 0  {Reset to an empty game, discarding any changes}
menuText Q GameFirst "Load First Game" 5 {Load the first filtered game}
menuText Q GamePrev "Load Previous Game" 5 {Load the previous filtered game}
menuText Q GameReload "Re-Load Current Game" 3  {Reload this game, discarding any changes made}
menuText Q GameNext "Load Next Game" 7 {Load the next filtered game}
menuText Q GameLast "Load Last Game" 8 {Load the last filtered game}
menuText Q GameRandom "Load Random Game" 8 {Load a random filtered game}
menuText Q GameNumber "Load Game Number..." 5  {Load a game by entering its number}
menuText Q GameReplace "Save: Replace game..." 6  {Save this game, replacing the old version}
menuText Q GameAdd "Save: Add New Game..." 6  {Save this game as a new game in the database}
menuText Q GameDeepest "Identify Opening" 0 {Goto the deepest game position listed in the ECO book}
menuText Q GameGotoMove "Goto Move Number..." 5  {Go to a specified move number in the current game}
menuText Q GameNovelty "Find Novelty..." 7  {Find the first move of this game that has not played before}
menuText Q Search "Search" 0
menuText Q SearchReset "Reset Filter" 0 {Reset the filter so all games are included}
menuText Q SearchNegate "Negate Filter" 0 {Negate the filter to only include excluded games}
menuText Q SearchCurrent "Current Board..." 0 {Search for the current board position}
menuText Q SearchHeader "Header..." 0 {Search by Header (player, event, etc) information}
menuText Q SearchMaterial "Material/Pattern..." 0 {Search for material or board patterns}
menuText Q SearchUsing "Using Search File..." 0 {Search using a SearchOptions file}
menuText Q Windows "Windows" 0
menuText Q WindowsComment "Comment Editor" 0 {Open/close the comment editor}
menuText Q WindowsGList "Game List" 0 {Open/close the game list window}
menuText Q WindowsPGN "PGN Window" 0 {Open/close the PGN (game notation) window}
menuText Q WindowsPList "Player Finder" 2 {Open/close the player finder}
menuText Q WindowsTmt "Tournament Finder" 2 {Open/close the tournament finder}
menuText Q WindowsSwitcher "Database switcher" 0  {Open/close the Database Switcher window}
menuText Q WindowsMaint "Maintenance Window" 0  {Open/close the Maintenance window}
menuText Q WindowsECO "ECO Browser" 0 {Open/close the ECO Browser window}
menuText Q WindowsRepertoire "Repertoire Editor" 0  {Open/close the opening repertoire editor}
menuText Q WindowsStats "Statistics Window" 0  {Open/close the filter statistics window}
menuText Q WindowsTree "Tree Window" 0 {Open/close the Tree window}
menuText Q WindowsTB "Endgame Tablebase Window" 1  {Open/close the Tablebase window}
menuText Q Tools "Tools" 0
menuText Q ToolsAnalysis "Analysis Engine..." 0  {Start/stop a chess analysis engine}
menuText Q ToolsAnalysis2 "Analysis Engine 2..." 16  {Start/stop the 2nd chess analysis engine}
menuText Q ToolsCross "Crosstable" 0 {Show tournament crosstable for this game}
menuText Q ToolsEmail "Email Manager" 0  {Open/close the email chess manager window}
menuText Q ToolsFilterGraph "Filter Graph" 7  {Open/close the filter graph window}
menuText Q ToolsOpReport "Opening Report" 0  {Generate an opening report for the current position}
menuText Q ToolsTracker "Piece Tracker"  6 {Open the Piece Tracker window}
menuText Q ToolsCoach "Play with coach"  0 {Start a game with a coach and tactical opportunities}
menuText Q ToolsBookTuning "Book tuning" 0 {Change percentages of moves played in opening}
menuText Q ToolsPInfo "Player Information"  0  {Open/update the Player Information window}
menuText Q ToolsPInfoBlack "Black"  0  {Open/update the Player Information window for the Black player}
menuText Q ToolsPInfoWhite "White"  0  {Open/update the Player Information window for the White player}
menuText Q ToolsPlayerReport "Player Report..." 3  {Generate a player report}
menuText Q ToolsRating "Rating Graph" 0  {Graph the rating history of the current game players}
menuText Q ToolsScore "Score Graph" 0 {Show the score graph window}
menuText Q ToolsExpCurrent "Export Current Game" 8  {Write current game to a PGN, HTML or LaTeX file}
menuText Q ToolsExpCurrentPGN "Export Game to PGN File..." 15  {Write current game to a PGN file}
menuText Q ToolsExpCurrentHTML "Export Game to HTML File..." 15  {Write current game to a HTML file}
menuText Q ToolsExpCurrentLaTeX "Export Game to LaTeX File..." 15  {Write current game to a LaTeX file}
menuText Q ToolsExpFilter "Export All Filter Games" 1  {Write all filtered games to a PGN, HTML or LaTeX file}
menuText Q ToolsExpFilterPGN "Export Filter to PGN File..." 17  {Write all filtered games to a PGN file}
menuText Q ToolsExpFilterHTML "Export Filter to HTML File..." 17  {Write all filtered games to a HTML file}
menuText Q ToolsExpFilterLaTeX "Export Filter to LaTeX File..." 17  {Write all filtered games to a LaTeX file}
menuText Q ToolsImportOne "Import One PGN Game..." 0  {Import a game from PGN text}
menuText Q ToolsImportFile "Import File of PGN Games..." 7  {Import games from a PGN file}
menuText Q ToolsImportDir "Import all PGN files in a directory" 16  {Imports all the PGN files in a particular directory}
menuText Q ToolsDownload "Download Games from..." 0 {Download games from the internet}
menuText Q ToolsDownloadNotes     "README first!!"  0 {Notes about downloading games within ChessDB}
menuText Q ToolsDownloadFromICC   "ICC"  0 {Download the most recent games of anyone on ICC}
menuText Q ToolsDownloadFromFICS  "FICS" 0 {Download the most recent games of anyone on FICS}
menuText Q ToolsDownloadFromTWIC "TWIC" 0   {Download games in PGN format from the TWIC web site (these are updated weekly!!)}
menuText Q ToolsDownloadSourceforge "http://chessdb.sourceforge.net (a huge database, #1 site)" 0   {Gives you a large database of over 3.5 million games. Packaged for easy(ish) downloading. 1st choice site.}
menuText Q ToolsDownloadSourceforge100000 "100,000 game database (site #1)" 0   {Gives you a database of 100000 games. Packaged for easy(ish) downloading. 1st choice site.}
menuText Q ToolsDownloadChesstutor100000 "100,000 game database (site #2)" 0   {Gives you a database of 100000 games. Packaged for easy(ish) downloading. 2nd choice site.}

menuText Q ToolsDownloadSourceforgeJustBig  ">3.5 million game database (site #1)" 0   {Gives you a huge database of over 3.5 million games. Packaged for easy(ish) downloading. 1st choice site.}
menuText Q ToolsDownloadChesstutorJustBig ">3.5 million game database (site #2)" 0   {Gives you a huge database of over 3.5 million games. Packaged for easy(ish) downloading. 2nd choice site.}

menuText Q ToolsDownloadBookup "bookup.com" 0 {A collection of 500 pgn files, each containing games of a specific ECO code (A00 to E99)}

menuText Q Options "Options" 0
menuText Q OptionsBoard "Chessboard" 0 {Chess board appearance options}
menuText Q OptionsBoardSize "Size" 0 {Change the board size}
menuText Q OptionsBoardPieces "Piece Style" 6 {Change the board piece style}
menuText Q OptionsBoardColors "Colors..." 0 {Change board colors}
menuText Q OptionsBoardNames "My Player Names..." 0 {Edit my player names}
menuText Q OptionsExport "Exporting" 0 {Change text export options}
menuText Q OptionsFonts "Fonts" 0 {Change fonts}
menuText Q OptionsFontsRegular "Regular" 0 {Change the regular font}
menuText Q OptionsFontsMenu "Menu" 0 {Change the menu font}
menuText Q OptionsFontsSmall "Small" 0 {Change the small font}
menuText Q OptionsFontsFixed "Fixed" 0 {Change the fixed-width font}
menuText Q OptionsGInfo "Game Information" 0 {Game information options}
menuText Q OptionsLanguage "Language" 0 {Select menu language}
menuText Q OptionsMoves "Moves" 0 {Move entry options}
menuText Q OptionsMovesAsk "Ask Before Replacing Moves" 0  {Ask before overwriting any existing moves}
menuText Q OptionsMovesAnimate "Animation Time" 1  {Set the amount of time used to animate moves}
menuText Q OptionsMovesDelay "Autoplay Time Delay..." 1  {Set the time delay for autoplay mode}
menuText Q OptionsMovesCoord "Coordinate Move Entry" 0  {Accept coordinate-style move entry (e.g. "g1f3")}
menuText Q OptionsMovesSuggest "Show Suggested Moves" 0  {Turn on/off move suggestion}
menuText Q OptionsMovesKey "Keyboard Completion" 0  {Turn on/off keyboard move auto-completion}
menuText Q OptionsNumbers "Number Format" 0 {Select the number format}
menuText Q OptionsStartup "Startup" 3 {Select windows to open at startup}
menuText Q OptionsWindows "Windows" 0 {Window options}
menuText Q OptionsWindowsIconify "Auto-Iconify" 5  {Iconify all windows when the main window is iconified}
menuText Q OptionsWindowsRaise "Auto-Raise" 5  {Raise certain windows (e.g. progress bars) whenever they are obscured}
menuText Q OptionsSounds "Sounds..." 2 {Configure move announcement sounds}
menuText Q OptionsToolbar "Toolbar..." 0 {Configure the main window toolbar}
menuText Q OptionsECO "Load ECO File..." 7 {Load the ECO classification file}
menuText Q OptionsSpell "Load Spellcheck File..." 11  {Load the ChessDB spellcheck file}
menuText Q OptionsTable "Tablebase Directory..." 10  {Select a tablebase file; all tablebases in its directory will be used}
menuText Q OptionsRecent "Recent Files..." 0  {Change the number of recent files displayed in the File menu}
menuText Q OptionsSave "Save Options" 0  "Save all settable options to the file $::optionsFile"
menuText Q OptionsAutoSave "Auto-Save Options on Exit" 0  {Auto-save all options when exiting ChessDB}
menuText Q OptionsDownload "Downloads..." 0 {Configure Download settings}
menuText Q Help "Help" 0
menuText Q HelpContents "Contents" 0 {Show the help contents page}
menuText Q HelpIndex "Index" 0 {Show the help index page}
menuText Q HelpGuide "Quick Guide" 0 {Show the quick guide help page}
menuText Q HelpHints "Hints" 0 {Show the hints help page}
menuText Q HelpContact "Contact Info" 1 {Show the contact information help page}
menuText Q HelpTip "Tip of the Day" 0 {Show a useful ChessDB tip}
menuText Q HelpStartup "Startup Window" 0 {Show the startup window}
menuText Q HelpAbout "About ChessDB" 0 {Information about ChessDB}
menuText Q GInfoInformant "Configure informant values" 0
menuText Q HelpCheckForUpdates "Check for Updates" 0 {Check software revision - this requires an internet connection, as it connects to the Sourceforge web server}
menuText Q HelpBugs "Bugs" 0 {Known bugs in ChessDB}
menuText Q HelpBugsKnownAtRelease  "Known  at release date" 0 {Bugs known at the time of release}
menuText Q HelpBugsRecentlyFound  "Discovered since release" 0 {Recently discovered bugs - needs internet connection}
menuText Q GInfoHideNext "Hide Next Move" 0
menuText Q GInfoMaterial "Show Material Values" 0
menuText Q GInfoFEN "Show FEN" 5
menuText Q GInfoMarks "Show Colored Squares and Arrows" 5
menuText Q GInfoWrap "Wrap Long Lines" 0
menuText Q GInfoFullComment "Show Full Comment" 10
menuText Q GInfoPhotos "Show Photos" 5
menuText Q GInfoTBNothing "Tablebases: Nothing" 12
menuText Q GInfoTBResult "Tablebases: Result Only" 12
menuText Q GInfoTBAll "Tablebases: Result and Best Moves" 19
menuText Q GInfoDelete "(Un)Delete This Game" 4
menuText Q GInfoMark "(Un)Mark This Game" 4
menuText Q TreeFile "File" 0
menuText Q TreeFileSave "Save Cache File" 0 {Save the tree cache (.stc) file}
menuText Q TreeFileFill "Fill Cache File" 0  {Fill the cache file with common opening positions}
menuText Q TreeFileBest "Best Games List" 0 {Show the best tree games list}
menuText Q TreeFileBest2 "Best games" 0 {Show the best (higest rated) games in the tree}
menuText Q TreeFileRecent "Recent games" 0 {Show the most recent games of any rating}
menuText Q TreeFileRecentGood "Recent good games" 0 {Show recent good games, weighted by age and rating}
menuText Q TreeFileGraph "Graph Window" 0 {Show the graph for this tree branch}
menuText Q TreeFileCopy "Copy Tree Text to Clipboard" 1  {Copy the tree statistics to the clipboard}
menuText Q TreeFileClose "Close Tree Window" 0 {Close the tree window}
menuText Q TreeSort "Sort" 0
menuText Q TreeSortAlpha "Alphabetical" 0
menuText Q TreeSortECO "ECO Code" 0
menuText Q TreeSortFreq "Frequency" 0
menuText Q TreeSortScore "Score" 0
menuText Q TreeOpt "Options" 0
menuText Q TreeOptLock "Lock" 0 {Lock/unlock the tree to the current database}
menuText Q TreeOptTraining "Training" 0 {Turn on/off tree training mode}
menuText Q TreeOptAutosave "Auto-Save Cache File" 0  {Auto-save the cache file when closing the tree window}
menuText Q TreeHelp "Help" 0
menuText Q TreeHelpTree "Tree Help" 0
menuText Q TreeHelpIndex "Help Index" 0
menuText Q FinderFile "File" 0
menuText Q FinderFileSubdirs "Look in Subdirectories" 0
menuText Q FinderFileClose "Close File Finder" 0
menuText Q FinderSort "Sort" 0
menuText Q FinderSortType "Type" 0
menuText Q FinderSortSize "Size" 0
menuText Q FinderSortMod "Modified" 0
menuText Q FinderSortName "Name" 0
menuText Q FinderSortPath "Path" 0
menuText Q FinderTypes "Types" 0
menuText Q FinderTypesChessDB "ChessDB Databases" 0
menuText Q FinderTypesOld "Old-Format ChessDB Databases" 0
menuText Q FinderTypesPGN "PGN Files" 0
menuText Q FinderTypesEPD "EPD Files" 0
menuText Q FinderTypesRep "Repertoire Files" 0
menuText Q FinderHelp "Help" 0
menuText Q FinderHelpFinder "File Finder Help" 0
menuText Q FinderHelpIndex "Help Index" 0
menuText Q PListFile "File" 0
menuText Q PListFileUpdate "Update" 0
menuText Q PListFileClose "Close Player Finder" 0
menuText Q PListSort "Sort" 0
menuText Q PListSortName "Name" 0
menuText Q PListSortElo "Elo" 0
menuText Q PListSortGames "Games" 0
menuText Q PListSortOldest "Oldest" 0
menuText Q PListSortNewest "Newest" 2
menuText Q TmtFile "File" 0
menuText Q TmtFileUpdate "Update" 0
menuText Q TmtFileClose "Close Tournament Finder" 0
menuText Q TmtSort "Sort" 0
menuText Q TmtSortDate "Date" 0
menuText Q TmtSortPlayers "Players" 0
menuText Q TmtSortGames "Games" 0
menuText Q TmtSortElo "Elo" 0
menuText Q TmtSortSite "Site" 0
menuText Q TmtSortEvent "Event" 1
menuText Q TmtSortWinner "Winner" 0
menuText Q GraphFile "File" 0
menuText Q GraphFileColor "Save as Color PostScript..." 8
menuText Q GraphFileGrey "Save as Greyscale PostScript..." 8
menuText Q GraphFileClose "Close Window" 6
menuText Q GraphOptions "Options" 0
menuText Q GraphOptionsWhite "White" 0
menuText Q GraphOptionsBlack "Black" 0
menuText Q GraphOptionsBoth "Both" 1
menuText Q GraphOptionsPInfo "Player Info player" 0
menuText Q StatsFile "File" 0
menuText Q StatsFilePrint "Print to File..." 0
menuText Q StatsFileClose "Close Window" 0
menuText Q StatsOpt "Options" 0
menuText Q PgnFile "File" 0
menuText Q PgnFileCopy "Copy Game to Clipboard" 0
menuText Q PgnFilePrint "Print to File..." 0
menuText Q PgnFileClose "Close PGN Window" 10
menuText Q PgnOpt "Display" 0
menuText Q PgnOptColor "Color Display" 0
menuText Q PgnOptShort "Short (3-line) Header" 0
menuText Q PgnOptSymbols "Symbolic Annotations" 1
menuText Q PgnOptIndentC "Indent Comments" 0
menuText Q PgnOptIndentV "Indent Variations" 7
menuText Q PgnOptColumn "Column Style (one move per line)" 1
menuText Q PgnOptSpace "Space after Move Numbers" 1
menuText Q PgnOptStripMarks "Strip out Colored Square/Arrow Codes" 1
menuText Q PgnOptBoldMainLine "Use Bold Text for Main Line Moves" 4
menuText Q PgnColor "Colors" 0
menuText Q PgnColorHeader "Header..." 0
menuText Q PgnColorAnno "Annotations..." 0
menuText Q PgnColorComments "Comments..." 0
menuText Q PgnColorVars "Variations..." 0
menuText Q PgnColorBackground "Background..." 0
menuText Q PgnColorMain "Main line..." 0
menuText Q PgnColorCurrent "Current move background..." 1
menuText Q PgnColorNextMove "Next move background..." 0
menuText Q PgnHelp "Help" 0
menuText Q PgnHelpPgn "PGN Help" 0
menuText Q PgnHelpIndex "Index" 0
menuText Q CrosstabFile "File" 0
menuText Q CrosstabFileText "Print to Text File..." 9
menuText Q CrosstabFileHtml "Print to HTML File..." 9
menuText Q CrosstabFileLaTeX "Print to LaTeX File..." 9
menuText Q CrosstabFileClose "Close Crosstable Window" 0
menuText Q CrosstabEdit "Edit" 0
menuText Q CrosstabEditEvent "Event" 0
menuText Q CrosstabEditSite "Site" 0
menuText Q CrosstabEditDate "Date" 0
menuText Q CrosstabOpt "Display" 0
menuText Q CrosstabOptAll "All-play-all" 0
menuText Q CrosstabOptSwiss "Swiss" 0
menuText Q CrosstabOptKnockout "Knockout" 0
menuText Q CrosstabOptAuto "Auto" 1
menuText Q CrosstabOptAges "Ages in Years" 8
menuText Q CrosstabOptNats "Nationalities" 0
menuText Q CrosstabOptRatings "Ratings" 0
menuText Q CrosstabOptTitles "Titles" 0
menuText Q CrosstabOptBreaks "Tie-Break Scores" 4
menuText Q CrosstabOptDeleted "Include Deleted Games" 8
menuText Q CrosstabOptColors "Colors (Swiss table only)" 0
menuText Q CrosstabOptColumnNumbers "Numbered Columns (All-play-all table only)" 2
menuText Q CrosstabOptGroup "Group Scores" 0
menuText Q CrosstabSort "Sort" 0
menuText Q CrosstabSortName "Name" 0
menuText Q CrosstabSortRating "Rating" 0
menuText Q CrosstabSortScore "Score" 0
menuText Q CrosstabColor "Color" 0
menuText Q CrosstabColorPlain "Plain Text" 0
menuText Q CrosstabColorHyper "Hypertext" 0
menuText Q CrosstabHelp "Help" 0
menuText Q CrosstabHelpCross "Crosstable Help" 0
menuText Q CrosstabHelpIndex "Help Index" 0
menuText Q OprepFile "File" 0
menuText Q OprepFileText "Print to Text File..." 9
menuText Q OprepFileHtml "Print to HTML File..." 9
menuText Q OprepFileLaTeX "Print to LaTeX File..." 9
menuText Q OprepFileOptions "Options..." 0
menuText Q OprepFileClose "Close Report Window" 0
menuText Q OprepFavorites "Favorites" 1
menuText Q OprepFavoritesAdd "Add Report..." 0
menuText Q OprepFavoritesEdit "Edit Report Favorites..." 0
menuText Q OprepFavoritesGenerate "Generate Reports..." 0
menuText Q OprepHelp "Help" 0
menuText Q OprepHelpReport "Opening Report Help" 0
menuText Q OprepHelpIndex "Help Index" 0
menuText Q RepFile "File" 0
menuText Q RepFileNew "New" 0
menuText Q RepFileOpen "Open..." 0
menuText Q RepFileSave "Save..." 0
menuText Q RepFileSaveAs "Save As..." 5
menuText Q RepFileClose "Close Window" 0
menuText Q RepEdit "Edit" 0
menuText Q RepEditGroup "Add Group" 4
menuText Q RepEditInclude "Add Include Line" 4
menuText Q RepEditExclude "Add Exclude Line" 4
menuText Q RepView "View" 0
menuText Q RepViewExpand "Expand All Groups" 0
menuText Q RepViewCollapse "Collapse All Groups" 0
menuText Q RepSearch "Search" 0
menuText Q RepSearchAll "All of Repertoire..." 0
menuText Q RepSearchDisplayed "Displayed Lines Only..." 0
menuText Q RepHelp "Help" 0
menuText Q RepHelpRep "Repertoire Help" 0
menuText Q RepHelpIndex "Help Index" 0
menuText Q DownloadPGNFiles {Download PGN files} 0
menuText Q ToolsPlay "Play" 0 {Play game vs the computer, online, or engine vs engine}
menuText Q ToolsPlayYouBlack "Computer vs You" 0 {Play a game as Black against a chess engine}
menuText Q ToolsPlayYouWhite "You vs Computer" 0 {Play a game as White against a chess engine}
menuText Q ToolsPlayOnline "Play online" 0 {Play others on a chess server - requires an internet connection}
menuText Q SortEPDLines  "Sort EPD Lines" 1 {Sort EPD lines of file}
menuText Q SelectAllEPD  "Select all EPD Lines" 0 {Select all EPD lines}
menuText Q ToolsPlayEngineEngine "Computer vs Computer" 0 {Two chess computers play against each other}
menuText Q ToolsObserveChessServer "Observe online game" 0 {Observe a game being played on a chess server}
menuText Q HelpThanks "Thank you" 0 {A list of those who have helped ChessDB in some way}
menuText Q HelpHowYouCanHelp "How you can help" 0 {How you can improve ChessDB - even if you are not a programmer}
menuText Q HelpSupport "Support" 0 {How you can obtain support in using ChessDB - there is no charge for support}
menuText Q HelpLicense "ChessDB's licence conditions" 0 {Displays the GNU General Public License (GPL)}

# The code to switch to database slots was causing me problems, so I have 
# repeated this a few times. Sorry, but its a bit silly I know, but 
# could not find a better way to achieve what I wanted. 

menuText Q SwitchToDatabaseSlot1 "" 0 {Switch to database slot 1}
menuText Q SwitchToDatabaseSlot2 "" 0 {Switch to database slot 2}
menuText Q SwitchToDatabaseSlot3 "" 0 {Switch to database slot 3}
menuText Q SwitchToDatabaseSlot4 "" 0 {Switch to database slot 4}
menuText Q SwitchToDatabaseSlot5 "" 0 {Switch to database slot 5}
menuText Q SwitchToDatabaseSlot6 "" 0 {Switch to database slot 6}
menuText Q SwitchToDatabaseSlot7 "" 0 {Switch to database slot 7}
menuText Q SwitchToDatabaseSlot8 "" 0 {Switch to database slot 8}
menuText Q SwitchToClipbase      "" 0 {Switch to the clipbase (a database kept in memory, never written to disk)}
menuText Q History "History of ChessDB" 0 {Briefly outlines the history of the software}
menuText Q HelpConfigureFirewall "Using a firewall" 0 {Notes about using a firewall}
helpMsg Q .button.start {Go to start of game  (key: Home)}
helpMsg Q .button.end {Go to end of game  (key: End)}
helpMsg Q .button.back {Go back one move  (key: LeftArrow)}
helpMsg Q .button.forward {Go forward one move  (key: RightArrow)}
helpMsg Q .button.intoVar {Move into a variation  (shortcut key: v)}
helpMsg Q .button.exitVar {Leave the current variation  (shortcut key: z)}
helpMsg Q .button.flip {Rotate board  (shortcut key: .)}
helpMsg Q .button.coords {Turn board coordinates on or off  (shortcut key: 0)}
helpMsg Q .button.stm {Turn the side-to-move icon on or off}
helpMsg Q .button.autoplay {Autoplay moves  (key: Ctrl+Z)}
translate Q TitleDownloadFromTWIC {ChessDB: Download from TWIC website}
translate Q WebServerNotOK {The web server did NOT respond with an OK (HTTP status code 200) hence unable to retrieve}
translate Q GotoTWICNumber {First issue to download}
translate Q DownloadNow {Download now}
translate Q NotBelow210 {The TWIC web site does not archive issues older than 210}
translate Q TWICissuedDownloadedLast {issue(s) of TWIC downloaded }
translate Q OneTWICIssueDownloaded {One issue of TWIC was downloaded (issue}
translate Q TWICIssuesDownloaded {TWIC issues were download (issues}
translate Q BasedOnTheDate {Based on the date, the last issue ChessDB estimated that would be on the TWIC web site was issue}
translate Q soThisIsConsistant {so what you have retrieved is consistent with what ChessDB expected.}
translate Q soThisInNotConsistant {This is not consistent with what ChessDB managed to download. Perhaps there was a problem, or perhaps TWIC are late updating the web site. Or perhaps the date is wrong on your computer.}
translate Q TWICTitle {Downloads from The Week In Chess (TWIC)\n\n}
translate Q NoChangesMade {Failed to retrieve the first file requested. Aborting. No PGN file or database has been created.}
translate Q SomeFileButNotAll {Some, but not all of the files requested could be retrieved, so the database and/or PGN file will not have as many issues as you requested. Try another time, when TWIC have updated their web site}
translate Q TitlePartiallyCompleteDownload {Downloads partially completed}
translate Q FailureOccuredAt {The failure occured when trying to retrieve issue}
translate Q NoNewTWICIssueFound {No new TWIC issues were found - try again later, when TWIC may have updated their web site}
translate Q TriedButFailed {ChessDB tried unsuccessfully to retrieve issue}
translate Q TheNewDBAndOrPGN {The new ChessDB format database and/or PGN file, will be in the directory}
translate Q Introduction {Introduction}
translate Q Configuration {Configuration}
translate Q DeleteIndividualZip {Delete individual Zip files}
translate Q DeleteIndividualZip2 {Delete individual Zip files}
translate Q WhenTheyAreNoLongerNeeded  {when they are no longer needed.}
translate Q DeleteIndividualPGN {Delete individual PGN files}
translate Q DeleteIndividualPGN2 {Delete individual PGN files}
translate Q CreateLargePGN  {Create a large PGN of all PGN's downloaded}
translate Q CreateChessDBDatabase {Create database or EPD file}
translate Q ManuallySetFirstIssue {Manually set first issue         }
translate Q ManuallySetLastIssue  {Manually set last issue}
translate Q IssueNumber {Issue number}
translate Q IsNotAvailableYet {is not available yet}
translate Q DownloadResults {Download results}
translate Q DownloadShouldBeComplete {The download should be complete, although if you see this message very quickly, it probably means there was a problem.}
translate Q NeedWriteAccess  {This operation needs to write some file(s) to disk. It does this in the directory from where you started ChessDB, but in this case you don't have write access to that directory. Therefore this feature is not available to you. Please exit ChessDB, change directory to one where you have write access, then run ChessDB again. Then you will be able to use this feature.} 
translate Q NeedUnzip {The files on the TWIC web site are compressed and need 'unzip' to decompress them. If you do not have it, you can get the sources from http://www.info-zip.org/UnZip.html If you do have 'unzip', then make sure it is in the path, since ChessDB can't execute it. An 'unzip.exe' will be distributed with binary versions of ChessDB for Windows, so you should have unzip.exe if you installed a Windows binary}
translate Q WarningBeta  {WARNING: This copy of ChessDB is a 'beta' release, meaning it is intended mainly for testing and evaluation, but not really for everyday use. Beta releases may have significant bugs. Please use this 'beta' release only if you want the benefits (usually more functionality) and accept the higher risk of bugs. I would appreciate feedback, particularly on beta releases. Please check regularly for updates - you can do this from the Help menu.}
translate Q HelpTitleUpdatesMessage {Checking software version}
translate Q HelpUpdateStatusCurrent {Your version of ChessDB is current. It is version}
translate Q FreeUpgradeAt {Upgrades, when they are available, can be found for free at http://sourceforge.net/projects/chessdb/ All the stable releases are in a package called simply 'chessdb' Any beta releases, when available, will always be in a package called 'chessdb-unstable-for-testing'. Any extra files, such as tablebases, of perhaps games, will be in a package called 'extras'.}
translate Q ThisVersionIs {The version of ChessDB you currently using is}
translate Q HelpUpdateStatuStableToBeta  {However, that release is not considered a stable/bug-free release (hence you will find it in the 'chessdb-unstable-for-testing' package on Sourceforge and it has 'beta' in the name). While it will probably have some bug fixes, feature enhancements or completely new features compared to this stable release, there will often be a higher total number of bugs, and some new features shown on it may not work at all. Hence think about this before you download the beta release. But the best way to get ChessDB improved is to provide feedback on the bugs that exist. Beta releases will normally have more functionality than a stable release such as this, but are not as risky as alpha releases, so are often a good choice.}
translate Q UsingLatestStableNoLaterBeta {You are using the latest version of ChessDB. There is not even a later version at present for test purposes (a beta release). Well done! This is version}
translate Q UsingLatestStableThereIsLaterBeta {You are using the most current stable release of ChessDB. There is however a later 'beta' release available, but that is not fully tested and so is mainly for people who want to try out the latest features. There may well be significant enhancements, but some of the enhancements might not be fully functional. There is a greater chance of bugs in that case. It's up to you to decide whether or not to try the beta release. If you do, please provide feedback, as providing feedback on beta releases is the best way for ChessDB to improve.}
translate Q NotUsingLatestStableThereIsLaterBeta {You are not using the latest stable release of ChessDB, you are advised to upgrade to at least that as soon as possible.\nThere is also an even later 'beta' release available, but that is not fully tested and so is mainly for people who want to try out the latest features. There may well be significant enhancements in the beta release, but some of the enhancements might not be fully functional. There is a greater chance of bugs in that case. It's up to you to decide whether or not to try the beta release. If you do, please provide feedback, as providing feedback on beta releases is the best way for ChessDB to improve. but you are strongly advised to upgrade to at least the latest stable release.} 
translate Q NotUsingLatestStableButNoLaterBeta {There is a more recent release of ChessDB which is considered stable. That is not an experimental (beta) release, as there are currently no beta releases available. There is believed to be no reason for you not to upgrade.}
translate Q BetaButNotLatestBeta {You are using a beta version of ChessDB, but there is a later beta version available. Whilst the latest beta is not expected to be 100% perfect, it should be better than the version you are using. Hence you are strongly advised to upgrade to the latest beta release. Remember, please give feedback on versions of ChessDB, *especially* beta releases like this one, since beta versions are released primarily so people can spot bugs, before they are made into a stable release.}
translate Q VersionOfLatestStable {The latest stable release, which should be free of any significant problems, is version} 
translate Q ButNoteNotStable {But note that this is not classed as a stable release, so might well have bugs which don't exist in an older stable release. (Of course, a bug that existed in a stable release may be fixed in this beta one, but in general stable releases give the less hassle, but have less features.)}
translate Q VersionOfLatestBeta {The latest beta release is} 
translate Q DateOfRelease {That was released on}
translate Q WhichWasRelasedOn {which was released on}
translate Q HelpUpdateStatusUnknown {Sorry, unable to determine version.\nPlease check manually at http://chessdb.sourceforge.net/ or try again later.} 
translate Q HelpUpdateStatusCantConnect {Sorry, unable to connect to http://chessdb.sourceforge.net/ to find the current version of ChessDB. Please try again later.}
translate Q HelpUpdateStatusTooNew1 {This version appears to be newer that the latest release, which is a little odd, *unless* you have checked out code from the CVS repository, in which case ignore this message. Otherwise, please contact david.kirkby@onetel.net, telling him the date, time and version of your software (}
translate Q HelpUpdateStatusTooNew2 {) as well as the apparent latest version, which is}
translate Q Back {Back}
translate Q Browse {Browse}
translate Q Cancel {Cancel}
translate Q Clear {Clear}
translate Q Close {Close}
translate Q Contents {Contents}
translate Q Defaults {Defaults}
translate Q Delete {Delete}
translate Q Graph {Graph}
translate Q Help {Help}
translate Q Import {Import}
translate Q Index {Index}
translate Q LoadGame {Load Game}
translate Q BrowseGame {Browse Game}
translate Q MergeGame {Merge Game}
translate Q Preview {Preview}
translate Q Revert {Revert}
translate Q Save {Save}
translate Q Search {Search}
translate Q Stop {Stop}
translate Q Store {Store}
translate Q Update {Update}
translate Q ChangeOrient {Change window orientation}
translate Q ShowIcons {Show Icons}
translate Q None {None}
translate Q First {First}
translate Q Current {Current}
translate Q Last {Last}
translate Q game {game}
translate Q games {games}
translate Q move {move}
translate Q moves {moves}
translate Q all {all}
translate Q Yes {Yes}
translate Q No {No}
translate Q Both {Both}
translate Q King {King}
translate Q Queen {Queen}
translate Q Rook {Rook}
translate Q Bishop {Bishop}
translate Q Knight {Knight}
translate Q Pawn {Pawn}
translate Q White {White}
translate Q Black {Black}
translate Q Player {Player}
translate Q Rating {Rating}
translate Q RatingDiff {Rating difference (White - Black)}
translate Q AverageRating {Average Rating}
translate Q Event {Event}
translate Q Site {Site}
translate Q Country {Country}
translate Q IgnoreColors {Ignore colors}
translate Q Date {Date}
translate Q EventDate {Event date}
translate Q Decade {Decade}
translate Q Year {Year}
translate Q Month {Month}
translate Q Months {January February March April May June July August September October November December}
translate Q Days {Sun Mon Tue Wed Thu Fri Sat}
translate Q YearToToday {Year to today}
translate Q Result {Result}
translate Q Round {Round}
translate Q Length {Length}
translate Q ECOCode {ECO code}
translate Q ECO {ECO}
translate Q Deleted {Deleted}
translate Q SearchResults {Search Results}
translate Q OpeningTheDatabase {Opening database}
translate Q Database {Database}
translate Q Filter {Filter}
translate Q noGames {no games}
translate Q allGames {all games}
translate Q empty {empty}
translate Q clipbase {clipbase}
translate Q score {score}
translate Q StartPos {Start position}
translate Q Total {Total}
translate Q readonly {read-only}
translate Q ErrNotOpen {This is not an open database.}
translate Q ErrReadOnly {This database is read-only; it cannot be altered.}
translate Q ErrSearchInterrupted {Search was interrupted; results are incomplete.}
translate Q twin {twin}
translate Q deleted {deleted}
translate Q comment {comment}
translate Q hidden {hidden}
translate Q LastMove {Last move}
translate Q NextMove {Next move}
translate Q GameStart {Start of game}
translate Q LineStart {Start of line}
translate Q GameEnd {End of game}
translate Q LineEnd {End of line}
translate Q PInfoAll {Results for <b>all</b> games}
translate Q PInfoFilter {Results for <b>filter</b> games}
translate Q PInfoAgainst {Results against}
translate Q PInfoMostWhite {Most common openings as White}
translate Q PInfoMostBlack {Most common openings as Black}
translate Q PInfoRating {Rating history}
translate Q PInfoBio {Biography}
translate Q PInfoEditRatings {Edit Ratings}
translate Q Draw {Draw}
translate Q stalemate {stalemate}
translate Q withAllMoves {with all moves}
translate Q withAllButOneMove {with all but one move}
translate Q with {with}
translate Q only {only}
translate Q lose {lose}
translate Q loses {loses}
translate Q allOthersLose {all others lose}
translate Q matesIn {mates in}
translate Q hasCheckmated {has checkmated}
translate Q longest {longest}
translate Q WinningMoves {Winning moves}
translate Q DrawingMoves {Drawing moves}
translate Q LosingMoves {Losing moves}
translate Q UnknownMoves {Unknown-result moves}
translate Q Tip {Tip}
translate Q TipAtStartup {Tip at startup}
translate Q SaveCache {Save Cache}
translate Q Training {Training}
translate Q LockTree {Lock}
translate Q TreeLocked {locked}
translate Q TreeBest {Best}
translate Q TreeBestGames {Best Tree Games}
translate Q TreeRecentGames {Most recent tree games}
translate Q TreeTitleRow  {    Move   ECO       Frequency    Score  AvElo Perf AvYear %Draws}
translate Q TreeTotal {TOTAL}
translate Q FileFinder {File Finder}
translate Q FinderDir {Directory}
translate Q FinderDirs {Directories}
translate Q FinderFiles {Files}
translate Q FinderUpDir {up}
translate Q TmtLimit {List Limit}
translate Q TmtMeanElo {Mean Elo}
translate Q TmtNone {No matching tournaments were found.}
translate Q GraphFilterTitle {Filter Graph: frequency per 1000 games}
translate Q AddVariation {Add Variation}
translate Q AddMove {Add Move}
translate Q Annotate {Annotate}
translate Q AnnotateGames {Annotate a game or games}
translate Q AnalysisCommand {Analysis Command}
translate Q PreviousChoices {Previous Choices}
translate Q AnnotateTime {Set the time between moves in seconds}
translate Q AnnotateWhich {Add variations}
translate Q AnnotateAll {For moves by both sides}
translate Q AnnotateAllMoves {Annotate all moves}
translate Q AnnotateWhite {For White moves only}
translate Q AnnotateBlack {For Black moves only}
translate Q AnnotateNotBest {When game move is not best move}
translate Q AnnotateBlundersOnly {When game move is an obvious poor move}
translate Q AnnotateBlundersOnlyScoreChange {score from/to: }
translate Q MistakesThreshold {Score for weak move (?) }
translate Q BlundersThreshold {Score for blunder (??) }
translate Q StopBlunderAnalysisThreshold {Disregard when winning by at least }
translate Q LowPriority {Low CPU Priority}
translate Q ClickHereToSeeMoves {Click here to see moves}
translate Q ConfigureInformant {Configure Informant}
translate Q Informant!? {Interesting move}
translate Q Informant? {Poor move}
translate Q Informant?? {Blunder}
translate Q Informant?! {Dubious move}
translate Q Informant+= {White has a slight advantage}
translate Q Informant+/- {White has a moderate advantage}
translate Q Informant+- {White has a decisive advantage}
translate Q Informant++- {The game is considered won}


# Book window
translate Q Book {Book}

translate Q EngineList {Analysis Engine List}
translate Q EngineName {Name}
translate Q EngineCmd {Command}
translate Q EngineArgs {Parameters}
translate Q EngineDir {Directory}
translate Q EngineElo {Elo}
translate Q EngineTime {Date}
translate Q EngineNew {New}
translate Q EngineEdit {Edit}
translate Q EngineRequired {Fields in bold are required; others are optional}
translate Q PgnWindowTitle {Game Notation - game %u}
translate Q SetFilter {Set Filter}
translate Q AddToFilter {Add to Filter}
translate Q Swiss {Swiss}
translate Q Category {Category}
translate Q RepSearch {Repertoire Search}
translate Q RepIncludedLines {included lines}
translate Q RepExcludedLines {excluded lines}
translate Q RepCloseDialog {This repertoire has unsaved changes. Do you really want to continue and discard the changes you have made? }
translate Q HeaderSearch {Header Search}
translate Q EndSideToMove {Side to move at end of game}
translate Q GamesWithNoECO {Games with no ECO?}
translate Q GameLength {Game length}
translate Q FindGamesWith {Find games with flags}
translate Q StdStart {Non-standard start}
translate Q Promotions {Promotions}
translate Q Comments {Comments}
translate Q Variations {Variations}
translate Q Annotations {Annotations}
translate Q DeleteFlag {Delete flag}
translate Q WhiteOpFlag {White opening}
translate Q BlackOpFlag {Black opening}
translate Q MiddlegameFlag {Middlegame}
translate Q EndgameFlag {Endgame}
translate Q NoveltyFlag {Novelty}
translate Q PawnFlag {Pawn structure}
translate Q TacticsFlag {Tactics}
translate Q QsideFlag {Queenside play}
translate Q KsideFlag {Kingside play}
translate Q BrilliancyFlag {Brilliancy}
translate Q BlunderFlag {Blunder}
translate Q UserFlag {User}
translate Q PgnContains {PGN contains text}
translate Q GlistNumber {Number}
translate Q GlistWhite {White}
translate Q GlistBlack {Black}
translate Q GlistWElo {W-Elo}
translate Q GlistBElo {B-Elo}
translate Q GlistEvent {Event}
translate Q GlistSite {Site}
translate Q GlistRound {Round}
translate Q GlistDate {Date}
translate Q GlistYear {Year}
translate Q GlistEDate {EventDate}
translate Q GlistResult {Result}
translate Q GlistLength {Length}
translate Q GlistCountry {Country}
translate Q GlistECO {ECO}
translate Q GlistOpening {Opening}
translate Q GlistEndMaterial {End-Material}
translate Q GlistDeleted {Deleted}
translate Q GlistFlags {Flags}
translate Q GlistVars {Variations}
translate Q GlistComments {Comments}
translate Q GlistAnnos {Annotations}
translate Q GlistStart {Start}
translate Q GlistGameNumber {Game number}
translate Q GlistFindText {Find text}
translate Q GlistMoveField {Move}
translate Q GlistEditField {Configure}
translate Q GlistAddField {Add}
translate Q GlistDeleteField {Remove}
translate Q GlistWidth {Width}
translate Q GlistAlign {Align}
translate Q GlistColor {Color}
translate Q GlistSep {Separator}
translate Q GlistRemoveThisGameFromFilter  {Remove this game from Filter}
translate Q GlistRemoveGameAndAboveFromFilter  {Remove game (and all above it) from Filter}
translate Q GlistRemoveGameAndBelowFromFilter  {Remove game (and all below it) from Filter}
translate Q DatabaseName {Database Name:}
translate Q TypeIcon {Type Icon:}
translate Q NumOfGames {Games:}
translate Q NumDeletedGames {Deleted games:}
translate Q NumFilterGames {Games in filter:}
translate Q YearRange {Year range:}
translate Q RatingRange {Rating range:}
translate Q Description {Description}
translate Q Flag {Flag}
translate Q DeleteCurrent {Delete current game}
translate Q DeleteFilter {Delete filter games}
translate Q DeleteAll {Delete all games}
translate Q UndeleteCurrent {Undelete current game}
translate Q UndeleteFilter {Undelete filter games}
translate Q UndeleteAll {Undelete all games}
translate Q DeleteTwins {Delete twin games}
translate Q MarkCurrent {Mark current game}
translate Q MarkFilter {Mark filter games}
translate Q MarkAll {Mark all games}
translate Q UnmarkCurrent {Unmark current game}
translate Q UnmarkFilter {Unmark filter games}
translate Q UnmarkAll {Unmark all games}
translate Q Spellchecking {Spell-checking}
translate Q Players {Players}
translate Q Events {Events}
translate Q Sites {Sites}
translate Q Rounds {Rounds}
translate Q DatabaseOps {Database operations}
translate Q ReclassifyGames {ECO-classify games}
translate Q CompactDatabase {Compact database}
translate Q SortDatabase {Sort database}
translate Q AddEloRatings {Add Elo ratings}
translate Q AutoloadGame {Autoload game number}
translate Q StripTags {Strip PGN tags}
translate Q StripTag {Strip tag}
translate Q Backup {Backup database}
translate Q Cleaner {Cleaner}
translate Q CleanerHelp1 {The ChessDB Cleaner will perform all the maintenance actions you select from the list below, on the current database.}
translate Q CleanerHelp2 {Current settings in the ECO classification and twin deletion dialogs will apply if you select those functions.}
translate Q CleanerConfirm1 {Once Cleaner maintenance is started, it cannot be interrupted!}
translate Q CleanerConfirm2 {This may take a long time on a large database, depending on the functions you have selected and their current settings.}
translate Q CleanerConfirm3 {Are you sure you want to commence the maintenance functions you selected? }
translate Q AnnotationSymbols  {Annotation Symbols:}
translate Q Comment {Comment:}
translate Q InsertMark {Insert mark}
translate Q InsertMarkHelp {Insert/remove mark: Select color, type, square.}
translate Q InsertArrowHelp {Insert/remove arrow: Right-click two squares. }
translate Q GoodMove {Good move}
translate Q PoorMove {Poor move}
translate Q ExcellentMove {Excellent move}
translate Q Blunder {Blunder}
translate Q InterestingMove {Interesting move}
translate Q DubiousMove {Dubious move}
translate Q WhiteDecisiveAdvantage {White has a decisive advantage}
translate Q BlackDecisiveAdvantage {Black has a decisive advantage}
translate Q WhiteClearAdvantage {White has a clear advantage}
translate Q BlackClearAdvantage {Black has a clear advantage}
translate Q WhiteSlightAdvantage {White has a slight advantage}
translate Q BlackSlightAdvantage {Black has a slight advantage}
translate Q Equality {Equality}
translate Q Unclear {Unclear}
translate Q Diagram {Diagram}
translate Q BoardSearch {Board Search}
translate Q FilterOperation {Operation on current filter:}
translate Q FilterAnd {AND (Restrict filter)}
translate Q FilterOr {OR (Add to filter)}
translate Q FilterIgnore {IGNORE (Reset filter)}
translate Q SearchType {Search type:}
translate Q SearchBoardExact {Exact position (all pieces on same squares, any move order)}
translate Q SearchBoardExactPositionAndMoves {Exact position, reached by the same move order}
translate Q SearchBoardPawns {Pawns (same material, all pawns on same squares)}
translate Q SearchBoardFiles {Files (same material, all pawns on same files)}
translate Q SearchBoardAny {Any (same material, pawns and pieces anywhere)}
translate Q LookInVars {Look in variations}
translate Q MaterialSearch {Material Search}
translate Q Material {Material}
translate Q Patterns {Patterns}
translate Q Zero {Zero}
translate Q Any {Any}
translate Q CurrentBoard {Current Board}
translate Q CommonEndings {Common Endings}
translate Q CommonPatterns {Common Patterns}
translate Q MaterialDiff {Material difference}
translate Q squares {squares}
translate Q SameColor {Same color}
translate Q OppColor {Opposite color}
translate Q Either {Either}
translate Q MoveNumberRange {Move number range}
translate Q MatchForAtLeast {Match for at least}
translate Q HalfMoves {half-moves}
translate Q EndingPawns {Pawn endings}
translate Q EndingRookVsPawns {Rook vs. Pawn(s)}
translate Q EndingRookPawnVsRook {Rook and 1 Pawn vs. Rook}
translate Q EndingRookPawnsVsRook {Rook and Pawn(s) vs. Rook}
translate Q EndingRooks {Rook vs. Rook endings}
translate Q EndingRooksPassedA {Rook vs. Rook endings with a passed a-pawn}
translate Q EndingRooksDouble {Double Rook endings}
translate Q EndingBishops {Bishop vs. Bishop endings}
translate Q EndingBishopVsKnight {Bishop vs. Knight endings}
translate Q EndingKnights {Knight vs. Knight endings}
translate Q EndingQueens {Queen vs. Queen endings}
translate Q EndingQueenPawnVsQueen {Queen and 1 Pawn vs. Queen}
translate Q BishopPairVsKnightPair {Two Bishops vs. Two Knights middlegame}
translate Q PatternWhiteIQP {White IQP}
translate Q PatternWhiteIQPBreakE6 {White IQP: d4-d5 break vs. e6}
translate Q PatternWhiteIQPBreakC6 {White IQP: d4-d5 break vs. c6}
translate Q PatternBlackIQP {Black IQP}
translate Q PatternWhiteBlackIQP {White IQP vs. Black IQP}
translate Q PatternCoupleC3D4 {White c3+d4 Isolated Pawn Couple}
translate Q PatternHangingC5D5 {Black Hanging Pawns on c5 and d5}
translate Q PatternMaroczy {Maroczy Center (with Pawns on c4 and e4)}
translate Q PatternRookSacC3 {Rook Sacrifice on c3}
translate Q PatternKc1Kg8 {O-O-O vs. O-O (Kc1 vs. Kg8)}
translate Q PatternKg1Kc8 {O-O vs. O-O-O (Kg1 vs. Kc8)}
translate Q PatternLightFian {Light-Square Fianchettos (Bishop-g2 vs. Bishop-b7)}
translate Q PatternDarkFian {Dark-Square Fianchettos (Bishop-b2 vs. Bishop-g7)}
translate Q PatternFourFian {Four Fianchettos (Bishops on b2,g2,b7,g7)}
translate Q Today {Today}
translate Q ClassifyGame {Classify game}
translate Q EmptyBoard {Empty board}
translate Q InitialBoard {Initial board}
translate Q SideToMove {Side to move}
translate Q MoveNumber {Move number}
translate Q Castling {Castling}
translate Q EnPassantFile {En Passant file}
translate Q ClearFen {Clear FEN}
translate Q PasteFen {Paste FEN}
translate Q ReplaceMove {Replace move}
translate Q AddNewVar {Add new variation}
translate Q ReplaceMoveMessage1 {A move already exists here.}
translate Q ReplaceMoveMessage2 {You can replace it, discarding all moves after it, or add your move as a new variation.}
translate Q ReplaceMoveMessage3 {(You can avoid seeing this message in future by turning off the "Ask before replacing moves" option in the Options:Moves menu.)}
translate Q ReadOnlyDialog1 {If you make this database read-only, no changes will be permitted. No games can be saved or replaced, and no delete flags can be altered. Any sorting or ECO-classification results will be temporary.}
translate Q ReadOnlyDialog2 {You can easily make the database writable again, by closing and reopening it.}
translate Q ReadOnlyDialog3 {Do you really want to make this database read-only?}
translate Q ClearGameDialog {This game has been altered. Do you really want to continue and discard the changes made to it? }
translate Q ExitDialog {Do you really want to exit ChessDB?}
translate Q ExitUnsaved {The following databases have unsaved game changes. If you exit now, these changes will be lost.}
translate Q PasteCurrentGame {Paste current game}
translate Q ImportHelp1 {Enter or paste a PGN-format game in the frame above.}
translate Q ImportHelp2 {Any errors importing the game will be displayed here.}
translate Q ECOAllSections {all ECO sections}
translate Q ECOSection {ECO section}
translate Q ECOSummary {Summary for}
translate Q ECOFrequency {Frequency of subcodes for}
translate Q OprepTitle {Opening Report}
translate Q OprepReport {Report}
translate Q OprepGenerated {Generated by}
translate Q OprepStatsHist {Statistics and History}
translate Q OprepStats {Statistics}
translate Q OprepStatAll {All report games}
translate Q OprepStatBoth {Both rated}
translate Q OprepStatSince {Since}
translate Q OprepOldest {Oldest games}
translate Q OprepNewest {Newest games}
translate Q OprepPopular {Current popularity}
translate Q OprepFreqAll {Frequency in all years:   }
translate Q OprepFreq1   {In the  1 year  to today: }
translate Q OprepFreq5   {In the  5 years to today: }
translate Q OprepFreq10  {In the 10 years to today: }
translate Q OprepEvery {once every %u games}
translate Q OprepUp {up %u%s from all years}
translate Q OprepDown {down %u%s from all years}
translate Q OprepSame {no change from all years}
translate Q OprepMostFrequent {Most frequent players}
translate Q OprepMostFrequentOpponents {Most frequent opponents}
translate Q OprepRatingsPerf {Ratings and Performance}
translate Q OprepAvgPerf {Average ratings and performance}
translate Q OprepWRating {White rating}
translate Q OprepBRating {Black rating}
translate Q OprepWPerf {White performance}
translate Q OprepBPerf {Black performance}
translate Q OprepHighRating {Games with highest average rating}
translate Q OprepTrends {Result Trends}
translate Q OprepResults {Result lengths and frequencies}
translate Q OprepLength {Game length}
translate Q OprepFrequency {Frequency}
translate Q OprepWWins {White wins: }
translate Q OprepBWins {Black wins: }
translate Q OprepDraws {Draws:      }
translate Q OprepWholeDB {whole database}
translate Q OprepShortest {Shortest wins}
translate Q OprepMovesThemes {Moves and Themes}
translate Q OprepMoveOrders {Move orders reaching the report position}
translate Q OprepMoveOrdersOne {There was only one move order reaching this position:}
translate Q OprepMoveOrdersAll {There were %u move orders reaching this position:}
translate Q OprepMoveOrdersMany {There were %u move orders reaching this position. The top %u are:}
translate Q OprepMovesFrom {Moves from the report position}
translate Q OprepMostFrequentEcoCodes {Most frequent ECO codes}
translate Q OprepThemes {Positional Themes}
translate Q OprepThemeDescription {Frequency of themes in the first %u moves of each game}
translate Q OprepThemeSameCastling {Same-side castling}
translate Q OprepThemeOppCastling {Opposite castling}
translate Q OprepThemeNoCastling {Both Kings uncastled}
translate Q OprepThemeKPawnStorm {Kingside pawn storm}
translate Q OprepThemeQueenswap {Queens exchanged}
translate Q OprepThemeWIQP {White Isolated Queen Pawn}
translate Q OprepThemeBIQP {Black Isolated Queen Pawn}
translate Q OprepThemeWP567 {White Pawn on 5/6/7th rank}
translate Q OprepThemeBP234 {Black Pawn on 2/3/4th rank}
translate Q OprepThemeOpenCDE {Open c/d/e file}
translate Q OprepTheme1BishopPair {Only one side has Bishop pair}
translate Q OprepEndgames {Endgames}
translate Q OprepReportGames {Report games}
translate Q OprepAllGames    {All games}
translate Q OprepEndClass {Material at the end of each game}
translate Q OprepTheoryTable {Theory Table}
translate Q OprepTableComment {Generated from the %u highest-rated games.}
translate Q OprepExtraMoves {Extra note moves in theory table}
translate Q OprepMaxGames {Maximum games in theory table}
translate Q OprepViewHTML {View HTML}
translate Q OprepViewLaTeX {View LaTeX}
translate Q PReportTitle {Player Report}
translate Q PReportColorWhite {with the White pieces}
translate Q PReportColorBlack {with the Black pieces}
translate Q PReportMoves {after %s}
translate Q PReportOpenings {Openings}
translate Q PReportClipbase {Empty clipbase and copy matching games to it}
translate Q TrackerSelectSingle {Left mouse button selects this piece.}
translate Q TrackerSelectPair {Left mouse button selects this piece; right button also selects its sibling.}
translate Q TrackerSelectPawn {Left mouse button selects this pawn; right button selects all 8 pawns.}
translate Q TrackerStat {Statistic}
translate Q TrackerGames {% games with move to square}
translate Q TrackerTime {% time on each square}
translate Q TrackerMoves {Moves}
translate Q TrackerMovesStart {Enter the move number where tracking should begin.}
translate Q TrackerMovesStop {Enter the move number where tracking should stop.}
translate Q SelectAllGames {All games in the database}
translate Q SelectFilterGames {Only games in the filter}
translate Q SelectTournamentGames {Only games in the current tournament}
translate Q SelectOlderGames {Only older games}
translate Q TwinsNote1 {To be twins, two games must at least have the same two players, and criteria you can set below. When a pair of twins is found, the shorter game is deleted.}
translate Q TwinsNote2 {Hint: it is best to spellcheck the database before deleting twins, since it improves twin detection. }
translate Q TwinsCriteria {Criteria: Twin games must have...}
translate Q TwinsWhich {Examine which games}
translate Q TwinsColors {Same player colors?}
translate Q TwinsEvent {Same event?}
translate Q TwinsSite {Same site?}
translate Q TwinsRound {Same round?}
translate Q TwinsYear {Same year?}
translate Q TwinsMonth {Same month?}
translate Q TwinsDay {Same day?}
translate Q TwinsResult {Same result?}
translate Q TwinsECO {Same ECO code?}
translate Q TwinsMoves {Same moves?}
translate Q TwinsPlayers {Comparing player names:}
translate Q TwinsPlayersExact {Exact match}
translate Q TwinsPlayersPrefix {First 4 letters only}
translate Q TwinsWhen {When deleting twin games}
translate Q TwinsSkipShort {Ignore all games under 5 moves long?}
translate Q TwinsUndelete {Undelete all games first?}
translate Q TwinsSetFilter {Set filter to all deleted twin games?}
translate Q TwinsComments {Always keep games with comments?}
translate Q TwinsVars {Always keep games with variations?}
translate Q TwinsDeleteWhich {Delete which game:}
translate Q TwinsDeleteShorter {Shorter game}
translate Q TwinsDeleteOlder {Smaller game number}
translate Q TwinsDeleteNewer {Larger game number}
translate Q TwinsDelete {Delete games}
translate Q NameEditType {Type of name to edit}
translate Q NameEditSelect {Games to edit}
translate Q NameEditReplace {Replace}
translate Q NameEditWith {with}
translate Q NameEditMatches {Matches: Press Ctrl+1 to Ctrl+9 to select}
translate Q Classify {Classify}
translate Q ClassifyWhich {ECO-Classify which games}
translate Q ClassifyAll {All games (overwrite old ECO codes)}
translate Q ClassifyYear {All games played in the last year}
translate Q ClassifyMonth {All games played in the last month}
translate Q ClassifyNew {Only games with no ECO code yet}
translate Q ClassifyCodes {ECO Codes to use}
translate Q ClassifyBasic {Basic codes only ("B12", ...)}
translate Q ClassifyExtended {ChessDB extensions ("B12j", ...)}
translate Q NameFile {Name file}
translate Q GameFile {Game file}
translate Q Names {Names}
translate Q Unused {Unused}
translate Q Sizeb {Size (bytes)}
translate Q SizeKb {Size (kb)}
translate Q SizeMb {Size (Mb)}
translate Q CurrentState {Current State}
translate Q AfterCompaction {After compaction}
translate Q CompactNames {Compact name file}
translate Q CompactGames {Compact game file}
translate Q SortCriteria {Criteria}
translate Q AddCriteria {Add criteria}
translate Q CommonSorts {Common sorts}
translate Q Sort {Sort}
translate Q AddToExistingFile {Add games to an existing file?}
translate Q ExportComments {Export comments?}
translate Q ExportVariations {Export variations?}
translate Q IndentComments {Indent comments?}
translate Q IndentVariations {Indent variations?}
translate Q ExportColumnStyle {Column style (one move per line)?}
translate Q ExportSymbolStyle {Symbolic annotation style:}
translate Q ExportStripMarks {Strip square/arrow mark codes from comments?}
translate Q LoadGameNumber {Enter the game number to load:}
translate Q GotoMoveNumber {Goto move number:}
translate Q CopyGames {Copy games}
translate Q CopyConfirm1 {Do you really want to copy}
translate Q CopyConfirm2 {the [::utils::thousands $nGamesToCopy] filtered games }
translate Q CopyConfirm3 {in the database "$fromName" } 
translate Q CopyConfirm4 {to the database "$targetName"? }
translate Q CopyErr {Cannot copy games}
translate Q CopyErrSource {the source database}
translate Q CopyErrTarget {the target database}
translate Q CopyErrNoGames {has no games in its filter}
translate Q CopyErrReadOnly {is read-only}
translate Q CopyErrNotOpen {is not open}
translate Q LightSquares {Light squares}
translate Q DarkSquares {Dark squares}
translate Q SelectedSquares {Selected squares}
translate Q SuggestedSquares {Suggested move squares}
translate Q WhitePieces {White pieces}
translate Q BlackPieces {Black pieces}
translate Q WhiteBorder {White border}
translate Q BlackBorder {Black border}
translate Q FindNovelty {Find Novelty}
translate Q Novelty {Novelty}
translate Q NoveltyInterrupt {Novelty search interrupted}
translate Q NoveltyNone {No novelty was found for this game}
translate Q NoveltyHelp {ChessDB will find the first move of the current game that reaches a position not found in the selected database or in the ECO openings book.}
translate Q SoundsFolder {Sound Files Folder}
translate Q SoundsFolderHelp {The folder should contain the files King.wav, a.wav, 1.wav, etc}
translate Q SoundsAnnounceOptions {Move Announcement Options}
translate Q SoundsAnnounceNew {Announce new moves as they are made}
translate Q SoundsAnnounceForward {Announce moves when moving forward one move}
translate Q SoundsAnnounceBack {Announce when retracting or moving back one move}
translate Q Upgrading {Upgrading}
translate Q ConfirmOpenNew {This is an old-format (Scid 2) database that cannot be opened in ChessDB 3, but a new-format (ChessDB 3) version has already been created. Do you want to open the new-format version of the database?}
translate Q ConfirmUpgrade { This is an old-format (Scid 2) database. A new-format version of the database must be created before it can be used in ChessDB 3.  Upgrading will create a new version of the database; it will not edit or remove the original files.  This may take a while, but it only needs to be done one time. You can cancel if it takes too long. Do you want to upgrade this database now?}
translate Q RecentFilesMenu {Number of recent files in File menu}
translate Q RecentFilesExtra {Number of recent files in extra submenu}
translate Q MyPlayerNamesDescription1 { Enter a list of preferred player names below, one name per line. Wildcards (e.g. "?" for any single character, "*" for any sequence of characters) are permitted.}
translate Q MyPlayerNamesDescription2 {Every time a game with a player in the list is loaded, the main window chessboard will be rotated if necessary to show the game from that players perspective.}
translate Q showblunderexists {show blunder exists}
translate Q showblundervalue {show blunder value}
translate Q showscore {show score}
translate Q coachgame {coach game}
translate Q configurecoachgame {configure coach game}
translate Q Phalanxengine {Phalanx engine}
translate Q Coachengine {Coach engine}
translate Q difficulty {difficulty}
translate Q hard {hard}
translate Q easy {easy}
translate Q Playwith {Play with}
translate Q white {white}
translate Q black {black}
translate Q Play {Play}
translate Q Noblunder {No blunder}
translate Q blunder {blunder}
translate Q Noinfo {-- No info --}
translate Q selectCoachEngines {Select a Phalanx engine in the left list and a coach engine in the right list (a Crafty engine is preferable as coach)}
translate Q moveblunderthreshold {move is a blunder if loss is greater than}
translate Q limitanalysis {limit engine analysis time}
translate Q seconds {seconds}
translate Q Abort {Abort}
translate Q TitleCanNotWriteDir {Error: Can't write to directory}
translate Q CanNotWriteToDirectory {ChessDB was unable to write to the directory} 
translate Q TitleCanNotWriteFile {ChessDB: Error writing file} 
translate Q CanNotWriteFile {ChessDB was unable to open the following file for writing:} 
translate Q CanNotWriteFile2 {Check the disk space and permissions} 
translate Q CanNotReadFile {ChessDB was unable to read the following file:} 
translate Q TitleCanNotOpenFile {ChessdDB Error: Can't open file} 
translate Q OverwrriteFilesIfPresent {Overwrite files of the same name in}
translate Q OverwrriteDBFilesIfPresent {Overwrite the database files (.sg3, si3 & .sn3) in}
translate Q FilesFromTWICPlaced {Files from the TWIC web site will be put in} 
translate Q NewDatabaseWillBeCreated {A new ChessDB database will be created in }
translate Q NewPGNWillBeCreated {A new PGN file will be created, which will hold the contents of all the files downloaded from the TWIC website. The new PGN file will be:}
translate Q ProblemWithWriteAcessToDatabaseFiles {You chose to create a database, but one or more of the database files exists. Since you chose not to overwrite the database files, this can not be done. Either don't create the database, move or delete the database files or change the tickbox to overwrite the database files in}
translate Q Appending {Appending}
translate Q ToTheEndOf {on to the end of}
translate Q ActionsToBePerformed {Actions to be performed}
translate Q DownloadLog {Log of actions performed}
translate Q DatabaseCreated {A new database 'newgames' has been created, based on the contents of the TWIC web site}
translate Q NewPGNCreated {A new PGN file 'newgames.pgn' has been created, based on the contents of the TWIC web site}
translate Q Warning {Warning:}
translate Q ErrorsDetectedWhenCreatingDatabase {Some errors were detected when creating the database. They were:}
translate Q AutomaticallyDetermineNextDownload {Automatically set first issue to download}
translate Q DownloadToLastCopyOnTWICWebSite {Download to the latest issue}
translate Q ShouldYouChose {Should you chose to use use the automatic method to determine the first issue to download, next time the program will start on issue}
translate Q CreateNeither {You selected neither to create a database or the large PGN file. Therefore there is nothing to do!}
translate Q IfUsingManualYouMustEnterValue {If you select to manually choose an issue or issues to download, you must enter a value. This will need to be between 210 and the latest issue on TWIC. Based on the clock in your computer, the latter is estimated to be approximately}
translate Q FileCorruption {ChessDB Error: File Corrupted}
translate Q TheLengthOfFileIsNotCorrect {The following file should be of 4 or 5 bytes long, but it is not:}
translate Q FirstIssueInFileTooLarge1 {The file}
translate Q FirstIssueInFileTooLarge2 {requests downloads start at issue}
translate Q FirstIssueInFileTooLarge3 {but that is unrealistically large. First check the date on your computer, as the estimate of what is unrealistic or not is based on the date. If the date is correct, set the first issue manually this time only, just in case it was an odd case of corruption. Check for an updated version of ChessDB (see 'Check for Updates' in the 'Help' menu)}
translate Q ReportPossibleInternalError {Please  email chessdb-users@lists.sourceforge.net to report this, since this should generally not happen and may indicate an internal error in ChessDB, which the developers would like to correct.}
translate Q butLastFileIndicates {but the file 'last-file.txt' indicates the next issue to download is less than that}
translate Q FirstIssueGreaterLastIssue {The first issue must be less than or equal to the last issue}
translate Q UserError {ChessDB: User Error}
translate Q TitleNeedUnzip {ChessDB: Unzip not found}
translate Q Needpgnchessdb {The executable program pgnchessdb can't be found - its impossible to continue without that.}
translate Q LookAtTutorial {Please look at the online tutorial at http://chessdb.sourceforge.net/tutorial/ The online documentation is always the most accurate, as the website is updated much more frequently than any other documentation.}
translate Q NumberOfHelpPages {ChessDB has 46 online help pages; just press F1 for help!}
translate Q AlsoViaICCorSkype {Support is available on The Internet Chess Club (ICC) too (send a tell to 'g8wrb' when he is online), or Skype to 'david-kirkby'.}
translate Q StartupCompleted {Start-up completed}
translate Q ReviewStartupCompleted {Review the above log to ensure you can make best use of ChessDB. You may need to configure a chess engine later.}
translate Q FoundThreePieceTablebases {You have only the 3-piece tablebases configured. These are all that comes with ChessDB, but the 4-piece and 5-piece can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/ (The 4-piece, but not 5-piece tablebases can also be downloaded from Sourceforge in the 'extras' package.) Be aware, the 5-piece tablebases require 7.1 GB of disk space - the 4-piece ones need a more modest 30 MB}
translate Q FoundFourPieceTablebases {You have at least some (possibly all) of the 4-piece tablebases configured, but do not have any 5-piece ones. The 5-piece tablebases can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/, but be aware the complete set requires 7.1 GB of disk space, so you may prefer to use just the 4-piece ones you have configured.}
translate Q FoundFivePieceTablebases {You have at least some (possibly all) of the 5-piece tablebases configured. They are the largest ChessDB supports. You are advised to make sure you have them all - any missing ones can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/}
translate Q CheckingForTablebaseFiles {Checking for Nalimov endgame tablebase files...}
translate Q ChessDBWebsite {Website: http://chessdb.sourceforge.net/}
translate Q ChessDBBasedOnScid {ChessDB is based on Scid -  http://scid.sourceforge.net/ but has new features, enhancements and bug-fixes. More than 90% of ChessDB's code comes from Scid.}
translate Q MainScidAuthor {The main author of Scid was Shane Hudson}
translate Q ShaneNoBugs {Shane is NOT responsible for any bugs in ChessDB}
translate Q SeeTutorial {Please see the online tutorial at http://chessdb/sourceforge.net/tutorial/}
translate Q GPL {ChessDB is distributed under the terms of the GNU General Public License}
translate Q Copyright {Copyright (C)}
translate Q AboutChessDB {About ChessDB}
translate Q FastStart {Fast start: no tablebases, ECO or spelling file loaded.}
translate Q TryECO {Trying to load the ECO openings file...}
translate Q CantLoadSpellcheck {Unable to load the default spellcheck file}
translate Q ErrorCantLoadDatbase {Error: could not open database}
translate Q Email {Email:}
translate Q TextAt {Text at}
translate Q start {start}
translate Q end {end}
translate Q file {file}
translate Q ResetToDefault {Reset to default}
translate Q SetPGNFileExportText {ChessDB: Set PGN file export text}
translate Q SetHTMLFileExportText {ChessDB: Set HTML file export text}
translate Q SetLaTexFileExportText {ChessDB: Set LaTex file export text}
translate Q ErrorOpening {Error opening}
translate Q ErrorOpeningEPDFile {Error opening EPD file}
translate Q OpeningEPDFile {Opening EPD file:}
translate Q OpeningRepertoireFile {Opening repertoire file:}
translate Q UnableToMergeGame {Unable to merge the selected game:}
translate Q SubscribeToMailingList {Please subscribe to the chessdb-users@lists.sourceforge.net mailing list by visiting https://lists.sourceforge.net/lists/listinfo/chessdb-users}
translate Q SettingUpAudio {Setting up audio move announcement...}
translate Q SeachingSounds {Searching sounds folder for move announcement sounds...}
translate Q NoSnack {Move speech disabled - Snack sound package 2.0 or later was not found}
translate Q Snack {Move speech enabled - Snack sound package 2.0 or later was found}
translate Q ConfigureSoundDir {Although you have the sound package installed, not all sounds were found. Select the directory from the Options Menu}
translate Q Found {Found}
translate Q of {of}
translate Q soundFilesIn {sound files in}
translate Q WarningUnknownOption {Warning: unknown option:}
translate Q TryingToLoadTheECOOpeningsFile {Trying to load the ECO openings file...}
translate Q UnableToOpenTheECOOpeningsFile {Unable to open the ECO file:}
translate Q ConfiguringSpellingAndRatings {Configuring spellings and ratings - please wait.}
translate Q TryingToLoadTheSpellingFile {Since the spelling and rating file (ratings.ssp) was not found, ChessDB will try to load the spellcheck file without ELO ratings (spelling.ssp)}
translate Q TryingToLoadTheSpellingAndRatingsFile {First trying to load the spellcheck file which has ELO ratings too:}
translate Q ThisCanBeSlowToLoad {This can be slow to load, so if you do not want to add ELO ratings, use spelling.ssp instead, which will load much faster.}
translate Q UnableToOpenTheSpellCheckFile {Unable to open the spellcheck only file either}
translate Q UnableToOpenTheSpellingAndRatingsFile {Unable to open the spellcheck and rating file:}
translate Q NeitherSpellingOrRatingFilesFound {Neither the spelling+rating file (ratings.ssp) or the spellcheck only file (spelling.ssp) could be loaded. These were included with ChessDB. You may need to set the directory on the Options menu}
translate Q positions {positions}
translate Q SpellcheckFile {Spellcheck file}
translate Q SpellcheckAndRatingsFile {Spellcheck and ratings file}
translate Q loaded {loaded}
translate Q DocumentationAndSupport {Documentation and support}
translate Q CopyrightHistoryLicence {Copyright, History and License}
translate Q NoTablebasesFoundUNIX {No Nalimov endgame tablebases were found, so endgame performance will be less than optimal. The 3 and 4-piece tablebases (which take up about 30 MB) are available on the ChessDB web site and will at some point be put into Debian and Solaris packages under the name chessdb-extras. The 5 piece tablebases (which use about 7.1 GB of disk space) can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/}
translate Q NoTablebasesFoundWindows {No Nalimov endgame tablebases were found. The small 3-piece tablesbases are included in ChessDB in a directory 'tablebases' so you should configure ChessDB to use them by setting the Tablebase Directory on the Options menu. The 4 piece tablebases (which take up about 30 MB) and 5 piece tablebases (which use about 7.1 GB of disk space) are not included in ChessDB due to their size. They can be downloaded from ftp://ftp.cis.uab.edu/pub/hyatt/TB/3-4-5/ (The 4-piece, but *not* 5-piece tablebases can also be downloaded from Sourceforge in ChessDB's 'extras' package)}
translate Q ConvertNullMovesToComments {Convert null moves to comments}
translate Q Random {Random}
translate Q GotoTheFirstPageOfGames {Go to the first page of games}
translate Q GotoTheLastPageOfGames {Go to the last page of games}
translate Q PreviousPageOfGames {Previous page of games}
translate Q NextPageOfGames {Next page of games}
translate Q NoGamesInCurrentFiler {There are no games in the current filter}
translate Q ChessDBSaveGameList {ChessDB: Save Game List}
translate Q SavingGameList {Saving game list...}
translate Q databases {databases}
translate Q All {All}
translate Q files {files}
translate Q TooManyDatabasesOpen {Too many databases open; close one first}
translate Q OpenAChessDBFile {Open a ChessDB file}
translate Q ErrorOpeningFile {ChessDB: Error opening file}
translate Q UnableToUpgradeTheDatabase {Unable to upgrade the database}
translate Q Opening {Opening}
translate Q ReadOnly {read-only...}
translate Q text {text}
translate Q HashChessDBOptiomFile {ChessDB options file}
translate Q HashInTclFormat {This file contains commands in the Tcl language format}
translate Q HashVersion    {Version:}
translate Q HashIfYouEdit {If you edit this file, you must preserve its valid Tcl}
translate Q HashformatOrNotSet {format or it will not set your ChessDB options properly}
translate Q ProxyHost {HTTP Proxy Host}
translate Q ProxyPort {HTTP Proxy Port}
translate Q Logo {Thanks to James Mossop who designed the logo.}
translate Q DownloadOptions {ChessDB: Download options}
translate Q ICCuser { ICC username}
translate Q FICSuser { FICS username}
translate Q ICCserver {ICC server}
translate Q FICSserver {FICS server}
translate Q ICCpass {ICC password}
translate Q FICSpass {FICS password}
translate Q Port {Port}
translate Q SavePassword {Save password}
translate Q NotEncrypted {WARNING: Saved as plain text - not encrypted at all.}
translate Q WeakEncryption {WARNING: Only a very weak encryption is used.}
translate Q ExtraTags {Extra Tags}
translate Q AsLastGame {As last game}
translate Q Databases {Databases}
translate Q Notation {Notation}
translate Q UpToMove {Up to move}
translate Q OK {OK}
translate Q bitmaps {bitmaps}
translate Q bitmaps2 {bitmaps2}
translate Q AutoCloseAfterStartup {Auto-close after startup}
translate Q SelectUptoFour1 {Select up to 4 table base *directories*}
translate Q ByClicking {By clicking any tablebase *file* in a directory}
translate Q IKnowConfusing {This bit is a bit confusing I know, but it verifies the tablebases are compatible}
translate Q LookingForOptionsFile {Looking for your options file}
translate Q OptionsFound {Your options file}
translate Q WasFoundAndLoaded {was found and loaded}
# The text is printed is "$DownloadGamesFromPre $server $DownloadGamesFromPost"
# so by setting either the pre or the post item, you can have your text 
# either before or after the server name. 
translate Q DownloadGamesFromPre {Download games from}
translate Q DownloadGamesFromPost { }
translate Q OnlyCompleteGames {Completed games only}
translate Q CompletedAndAdjourned {Completed and adjourned games}
translate Q Download {Download}
translate Q UsernamesFromFile {usernames from file}
translate Q UsernamesFromList {usernames from list}
translate Q ChessDBChooseECORange {ChessDB: Choose ECO Range}
translate Q ChessDBSearchOptionsFiles {ChessDB SearchOptions files}
translate Q UnabletocreateSearchOptionsfile {Unable to create SearchOptions file:}
translate Q Textfile {Text file}
translate Q CreateSearchOptionsfile {Create a SearchOptions file}
translate Q CreateListOf {Create list of}
translate Q usernames {usernames}
translate Q UnableToCreatelistOfUsername {Unable to create a list of user names}
translate Q HeaderSearchOptionSsavedTo {Header search options saved to}
translate Q UserNameList {User name list}
translate Q MainHelpIndex {Index of all help pages} 
translate Q HelpOnDownloadingChessServer {Help on downloading games from}
translate Q Connectto {Connect to}
translate Q CloseConnection {Close connection}
translate Q ConfigureSettings {Set server, username, password and port}
translate Q OutputFromChessServer {Output from the chess server will be shown here}
translate Q CurrentlyOnlyDemo {This part of the code is currently NON-FUNCTIONAL, as it has not been developed fully at this time.}
translate Q CommandToChessServer {Once connected, commands typed here will be sent to the chess server}
translate Q Login {Login}
translate Q Logout {Logout} 
translate Q ZipfileTooShort {The Zip File is too small (< 5000 bytes) to be one of TWIC's Zip files. Aborting....}
translate Q TitleZipfileTooShort {The Zip File is too small}
translate Q TitleUnliklyLastIssue {Last Issue is unrealistic}
translate Q UnliklyLastIssue1 {The last issue you requested is not a practical value. Based on the date on your computer, the last TWIC issue is estimated to be very approximately}
translate Q UnliklyLastIssue2 {Therefore a request for an issue of}
translate Q UnliklyLastIssue3 {or more is considered to be an error by ChessDB.}
translate Q UnliklyLastIssue4 {Therefore your request to retrieve up to issue}
translate Q UnliklyIssue      {will not be attempted. }
translate Q IfyouBeliveAnError {If you believe this is incorrect, please check the date on your computer, check for an updated version of ChessDB, or email chessdb-users@lists.sourceforge.net for further advice.}
translate Q UnliklyFirstIssue1 {The first issue you requested is not a practical value. Based on the date on your computer, the latest TWIC issue is estimated to be very approximately}
translate Q UnliklyFirstIssue2 {so a request for issues starting at}
translate Q UnliklyFirstIssue3 {or more is considered to be an error by ChessDB. Therefore your request to retrieve TWIC issues starting at}
translate Q ImportToCurrentDatabase {Import games to the current database}
translate Q CreateLargePGNofGames {Create a large PGN file of games}
translate Q AutomaticallySetFirstIssue {Automatically set first issue}
translate Q DoNothingAtAll {You have not chosen to create a large PGN file or to read games into the current database. Therefore there is nothing to do! Please go back and choose one or both of these}
translate Q GamesWillBeReadToCurrent {Games will be imported into the current database}
translate Q NewPGNandCurrent {If you selected 'Import games to the current database' the games should be there now. If you selected 'Create a large PGN file of games' the PGN file will be called 'newgames.pgn' in the directory}
translate Q CurrentDatabaseReadOnly {The current database is read-only, so you can not import games into it}
translate Q NotOpenDatabase {The current database is not open, so you can not import games into it} 
translate Q WarningCurrentDatabaseHasGames1 {The current database has}
translate Q WarningCurrentDatabaseHasGames2 {games in it. Importing games will not overwrite these, it will simply add the new games to the database. Please check that you have selected the right database - one would for example generally not want to add games from TWIC, ICC, or FICS to a database of your own games.}
translate Q WarningCurrentDatabaseHasGames3 {OK to proceed and download games into the current database?}
translate Q WarningCurrentDatabaseHasGames4 {games in it. Importing games will not overwrite these, it will simply add the new games to the current database.}
translate Q WarningCurrentDatabaseHasGames5 {Please check that you have the right database and the right directory. It is much easier to double-check now, than to try removing the games later if you accidently put them in the wrong database!}
translate Q WarningCurrentDatabaseHasGames6 {Continue, and import the games?}
translate Q WarningCurrentDBNotEmpty {Warning - the current database is not empty}
translate Q WithSomeEngines {With some engines, you will not see any analysis until the board changes. So if you see this message, try changing the board by moving backwards or forwards or making a new move.}
translate Q AnalysisEnginesList {Analysis engines list file for ChessDB}
translate Q Doyoureallywant {Do you really want to remove this engine from the list?}
translate Q TheNameCommand {The Name, Command and Directory fields must not be empty.}
translate Q NOTELogFileSizelimit {NOTE  : Log file size limit reached; closing log file.}
translate Q UnableToStartTheProgram {Unable to start the program:}
translate Q EngineCommunicationLog {ChessDB-Engine communication log file}
translate Q ThisFileWasAutomatically {This file was automatically generated by ChessDB.}
translate Q ItIsRewritten {It is rewritten every time an engine is started in ChessDB.}
translate Q ChessDBAnalysis {ChessDB: Analysis:}
translate Q QuietEngine {Quiet engine (still no output); sending it initial commands.}
translate Q Engine {Engine}
translate Q EngineTerminatedWithout {The analysis engine terminated without warning; it probably crashed or had an internal error. Don't try to use a 64-bit engine on a 32-bit computer, as that will never work!}
translate Q TitleEngineTerminatedWithout {ChessDB: Engine terminated unexpectidly}
translate Q SeenCrafty {Seen Crafty; assuming analyze and setboard commands.}
translate Q SetEngingThinkingTime {Set the engine thinking time per move in seconds:}
translate Q SorryNonStandard {Sorry, this game has a non-standard start position.}
translate Q ShareTags {Share tags}
translate Q undeletesBoth {undeletes both}
translate Q noTwin {no twin} 
translate Q NoDuplicatesDetectedFor {No duplicates detected for this game}
translate Q TwinGameChecker {Twin game checker}
translate Q ToShowTwinGams {To show twins using this window you must first use the 'Delete twin games' function}
translate Q Downloads {Downloads}
translate Q PreviousPair {Previous pair}
translate Q NextPair {Next pair}
translate Q ChessDBfound  {ChessDB found}
translate Q PlayerNameCorrections {player name corrections, the first}
translate Q areListedBelow {are listed below.}
translate Q EditTheList {Edit the list to remove any corrections you do not want.}
translate Q OnlyLinesOf {Only lines of the form:}
translate Q OldNameToNewName { 'Old Name' >> 'New Name'}
translate Q withNoSpaces {(with no spaces before the 'Old Name') are processed.}
translate Q Ambiguous {Ambiguous}
translate Q Surnames {Surnames}
translate Q YouCanDisreguardA {You can discard a correction you do not want by deleting its line, or simply by adding a space or any other character at the start of the line}
translate Q ToggleAnalysisBoard {Show/Hide Analysis Board}
translate Q ShowAnalysisBoard {Show Analysis Board}
translate Q HideAnalysisBoard {Hide Analysis Board}
translate Q Score {Score}
translate Q Depth {Depth}
translate Q Nodes {Nodes}
translate Q Time {Time}
translate Q YourMove {Your move...... }
translate Q Thinking {Thinking....... }
translate Q SetEngineThinkingTime {Set the engine thinking time per move in seconds:}
translate Q DoYouReally {Do you really want to remove this engine from the list?}
translate Q NameCommandAndDir {The Name, Command and Directory fields must not be empty.}
translate Q NoExtraTags {No extra tags were found}
translate Q FirstLineFrom {First line from engine seen; sending it initial commands now.}
translate Q Crafty18White {Crafty version is >= 18.0; assuming scores are from White perspective.}
translate Q TitleEnginethinkingtime {ChessDB Engine thinking time}
translate Q SoundOptions {Sound Options}
translate Q FreeChessDatabase {ChessDB: A free Chess Database}
translate Q UsingTclTkVersion {Using Tcl/Tk version:}
translate Q Maintainer {Maintainer: Dr. David Kirkby}
translate Q emailDave {Email: drkirkby@users.sourceforge.net}
translate Q SearchOptionsSaved {Material/pattern search options saved to file:}
translate Q TitleSearchOptionsSaved {Search Options saved}
translate Q ExtraTagsEgAnand {Extra Tags: (example format: Annotator "Anand, V")}
translate Q YouWereNotLoggedIn {You are not currently logged in to the chess server, so you can not log out}
translate Q TitleYouWereNotLoggedIn  {ChessDB: Logout error}
translate Q TitleCreateRepertore {Create a repertoire file}
translate Q NonStartedStartNoRepertoir {The current game does not have the standard starting position, so its positions cannot be added to the repertoire.}
translate Q RepetoireFiles {ChessDB repertoire files}
translate Q AreYouSureDeleteRepGroup {Are you sure you want to delete this group, keeping all the groups and lines under it?}
translate Q AreYouSureRecursivelyDeleteRepGroups {Are you sure you want to delete this group, AND ALL the groups and lines under it?}
translate Q AreYouSureDeleteLine {Are you sure you want to delete this line?}
translate Q TitleDeleteGroup {ChessDB: Delete group?}
translate Q TitleDeleteLine  {ChessDB: Delete line?}
translate Q NotLoggedOInNoDownload {You are not logged into the chess server, so can not download games. Please press 'Login' first.}
translate Q TitleNotLoggedOInNoDownload {Error: Not logged in}
translate Q ICCLimitOnGames {Note, the Internet Chess Club (ICC) limits the number of attempts that be made to download games in quick succession to 100. Once 100 have been attempted (whether or not they could all be downloaded), ICC server will simply reply "Game database temporarily unavailable". Since you have requested data on 6 or more players, each assumed to have 20 games in their history, this limit will be reached. After 100 attempts are made, there will be a long delay (x seconds), before any more are dowloads are attempted. ChessDB will resume once the ICC server will allow it. Note, the exact details of what limits the ICC server is programmed with are not known, so best guesses are used. If you see the message "Game database temporarily unavailable", please report the circumstances to the ChessDB mailing list.}
translate Q ICCLimitOnGames1 {Note, the Internet Chess Club (ICC) limits the number of attempts that be made to download games in quick succession to 100. Once 100 have been attempted (whether or not they could all be downloaded), ICC server will simply reply "Game database temporarily unavailable" It will stay like this for some time (approximately 80s)  before allowing further downloads}
translate Q ICCLimitOnGames2 {Since you have requested data on 6 or more players, each assumed to have 20 games in their history, this limit will be reached. After 100 attempts are made, there will be a long delay (80 seconds), before any more dowloads are attempted. ChessDB will resume once it believes the ICC server will allow it.}
translate Q ICCLimitOnGames3 {Note, the exact details of what limits the ICC server is programmed with are not known, so best guesses are used. If you see the message "Game database temporarily unavailable", please report the circumstances to the ChessDB mailing list. If you know the parameters ICC use, then please let us know, so best use can be made of this facility} 
translate Q TitleICCLimitOnGames {ICC database limit}
translate Q EmailAddressFields {Email address fields:}
translate Q Downloading {Please Wait !!}
translate Q DownloadsComplete {An attempt has been made to download the histories of all the players. If ICC's database became unavailable, (as it sometimes does with rapid downloads), then they may not be complete. Double check the number of games. Assuming you have all the games, you may close the database if you wish. You are still logged in, so log out if you wish.}

translate Q TitleDownloadsComplete {Downloads complete}
translate Q WillSlowNow {The downloads from ICC will slow now quite considerably, from one every 500 ms to one every 60 seconds. This is because the ICC server is configured to restrict the rate at which games can extracted from the database. A message will be printed when all games are downloaded - until then, please keep the database open. You can leave ChessDB unattended - perhaps take a break while the downloads continue at the reduced rate. }
translate Q WillSlowNow2 {If you want to get the games as fast as possible, save the database, log out, then back in again, after which you can download another 100 games very quickly.}
translate Q TitleWillSlowNow {Downloads will slow down}
translate Q DatabaseUnavailable {ICC's database is temporarily unavailable. This will happen if a lot of games are downloaded in a short time. ChessDB tries to avoid this, by slowing the rate of downloads after the first 100. However, as the exact conditions wwhich cause this to happen are unknown, it is difficult to do this well. If you get this message, please email chessdb-users-owner@lists.sourceforge.net and explain what you did. It is not an unusual message and is nothing to worry about.}
translate Q TitleDatabaseUnavailable {ICC database is temporarily unavailable}
translate Q LogInAnonymously {When connecting to ICC for the purpose of downloading games, it is suggested you do so anonymously. If not, anyone with you on their notify list will see ChessDB connect, which is probably not what you want. You can log into ICC anonymously by adding a "!" in front of your username. So if your ICC user name is "foobar", it is probably better to set it in ChessDB as "!foobar"}
translate Q TitleLogInAnonymously {Anonymous login}
translate Q ExtraSpacesBetweenUsernames {The list of user names must be separated by ONLY ONE SPACE. You have two or more spaces in the list. Please remove them.}
translate Q TitleExtraSpacesBetweenUsernames {User errror: Too many spaces}
translate Q SuccessfullySorted {The database was successfully sorted.}
translate Q TitleSortResults {ChessDB: Sort results}
translate Q ThisIsNotOpenNothingToSort {This is not an open database; there are no games to sort.}
translate Q WillAddEloRatings {This command will use the current spellcheck file to add Elo ratings to games in this database. Wherever a player has no currrent rating but his/her rating at the time of the game is listed in the spellcheck file, that rating will be added.}
translate Q OverwriteExistingNonZero {Overwrite existing non-zero ratings?}
translate Q AddRatingsTo {Add ratings to:}
translate Q AddedNElo {ChessDB added $r Elo ratings in $g games.}
##context 34fdjh AddedNElo {ChessDB added $r Elo ratings in $g games.}
translate Q AddedNElo1 {ChessDB added}
translate Q AddedNElo2 {Elo ratings in}

translate Q ExtraPGNTags {Extra PGN tags:}
translate Q RemoveAllOccurageOfTag {Do you really want to remove all occurences of the PGN tag}
# Then follows the database name, and after it
translate Q FromThisDatabase {from this database?}
translate Q RemovingThePGNTag {Removing the PGN tag}
# Then follows the name of a tag. 
translate Q ToSaveSpaceAnd {To save space and maintain database efficiency, it is a}
translate Q ToSaveSpaceAnd2 {good idea to compact the game file after removing tags.}
translate Q FindingGamesWithPGN {Finding games with the PGN tag}
# Then follows a database name
translate Q ChangeTheFollowingGame {Change the following game tags:}
translate Q Game {Game}
translate Q NoUnusedNames {There are no unused names, so the name file is already fully compacted.}
translate Q TheNameFile {The name file for the database}
#Then follows a database name
translate Q wasCompacted {was compacted.}
translate Q TitleErrorCompactingFile {ChessDB: Error compacting file}
translate Q TitleNameFileCompacted {ChessDB: Name file compacted}
translate Q TitleGameFileCompacted {ChessDB: Game file compacted}
translate Q TheGameFileIsAlreadyCompacted {The game file is already fully compacted.}
translate Q TheGameFile {The game  file for the database}
# Then follows a database name, and finally "was compacted."
# eg The game  file for the database GM-games was compacted.
translate Q YourSetting4Twins {Your settings for finding twin games are potentially likely to }
translate Q YourSetting4Twins2 {cause non-twin games with similar moves to be marked as twins.}
translate Q DoYouWantToContinueAndDelete {Do you want to continue and delete twin games anyway?}
translate Q ItIsReccomenedThatYou {It is recommended that you specify "Yes" for at least two of the "same site", "same round" and "same year" settings.}
translate Q ItIsReccommendedThatIf {It is recommended that if you select "No" for "same moves", you should select "Yes" for the colors, event, site, round, year and month settings} 
translate Q AllSettingNotEntered1 {You MUST configure a chess server name (usually chessclub.com for ICC and freechess.org for FICS), a username, a password and a port (usually 5000, but 23 might be useful in some cases).}
translate Q AllSettingNotEntered2 {Please set these either from the File menu of this window, or Options -> Downloads on the main ChessDB window.}
translate Q NeedLoginParamtersSet {Login parameters must be set}
translate Q UsernameNotReconised1 {The chess server does not reconsise the username of :}
translate Q ICCUsernameNotReconised2 {Have you got the right username for this server? Has your account expired? Check all settings CAREFULLY.}
translate Q TitleICCUsernameNotReconised {Unknown user name}
translate Q InvalidPassword {does not reconise that password given for the username }
translate Q TitleInvalidPassword {Invalid password}
translate Q ConnectionToChessSeverFailed {Connection to chess server failed. Is  your network connection OK? Is the firewall blocking traffic? The chess server could be down. The error message generated was:}
translate Q TitleConnectionToChessSeverFailed {Unable to connect to chess server}
translate Q TheSettingsUsed {The setting used when trying to connect were:}
translate Q LookingForSpellingFile {Looking for the spelling and ratings file "ratings.ssp"}
translate Q SpellCheckFileFound {The spell check and ratings file was found}
translate Q SpellCheckFileNotFound {The spell check file, which has the ELO ratings of players, could not be located. This was distributed with ChessDB with the name "ratings.ssp"}
translate Q OptionsFile {Options File}
translate Q UnableToFindOptions1 {Unable to find the options file}
translate Q UnableToFindOptions2 {A new options file will be created}
translate Q AttemptingToLoadTheSpellingAndRatingsFile {Attempting to load the spellcheck file which has ELO ratings too:}
translate Q KiloNodesPerSecond {kn/s}
translate Q IfYouWantTheseTablebases {If you want these tablebases to be used whenever you start ChessDB, select "Save Options" from the Options menu before you exit ChessDB.}
translate Q UnableToReadFromChessServer1 {An error occured when ChessDB tried to read from the chess server.}
translate Q UnableToReadFromChessServer2 {This can occur if there is a network problem, a fault at the chess server, you have logged out but a request from ChessDB to read has taken place (this is a bug that will be fixed later).}
translate Q ErrorMessage {The error message generated was:}
translate Q TitleReadFromChessSeverFailed {Unable to read from the chess server}
translate Q TitleWriteFromChessSeverFailed {Unable to write to chess server}
translate Q UnableToWriteToChessServer1 {An error occured when ChessDB tried to write to the chess server.}
translate Q UnableToWriteToChessServer2 {This can occur if there is a network problem, a fault at the chess server, you have logged out but a request from ChessDB to write has taken place (this is a bug that will be fixed later).}
translate Q IfYouWishToContinue {If you wish to continute to download  more files, it *may* be necessary to quit ChessDB and log in again (this is a bug that will be fixed later.)}
translate Q NoFICSYet1 {Although it is possible to download games into a database from ICC, this is not currently possible with FICS.}
translate Q NoFICSYet2 {FICS support will be added, but it is a bit more complex than on ICC, since FICS does not have the 'spgn' (or similar) command to show the PGN of a game. Expect FICS support by April or May 2007.}
translate Q TitleNoFICSYet {No support currently for download via FICS}
translate Q TitleImportFromAPGNFile {Import from a PGN file}
translate Q TitleImportingPGNFile {ChessDB: Importing PGN file}
translate Q TitleImportingPGNFiles {ChessDB: Importing PGN files}
translate Q NoPGNErrorsOrWarnings {with no PGN errors or warnings.}
translate Q PGNErrorsWarnings {PGN error/warnings:}
translate Q ImportingPGNgamesFrom {Importing PGN games from}
translate Q TitleSelectATablebaseFile {ChessDB: Select a Tablebase  file}
translate Q ChooseDirectoryWithPGN {Choose a directory containing one or more PGN files}
translate Q NoPGNFileInDir {It is not possible to import any PGN files, since there are no files with the extension .pgn or .PGN in the directory}
translate Q TitleNoPGNFileInDir {ChessDB Error: No PGN files in the directory}
translate Q ImportingNumber {This will import} 
translate Q PGNFilesFromDir {PGN files from the directory}
translate Q ToolsImportDirText {Import all the PGN files in a directory}
translate Q TitleChessDBError {ChessDB: Error}
translate Q ToHaveThisLoaded {To have this file automatically loaded when you start ChessDB, select "Save Options" from the Options menu before exiting.}
translate Q ECOfile {ECO file}
translate Q TitleChessDBECOFileLoaded {ChessDB: ECO file loaded.}
# Do NOT translate the following line - it is there to help translators only
##context Q gdgfgffggertldffdo {Importing file number 12 of 124}
##context E gdgfgffggertldffdo {Importing file number 12 of 124}
translate Q TablebasesWithUpto {Endgame tablebases with up to}
translate Q NPieces {pieces were found, so those tablebases will be used to allow ChessDB to perform an exact analysis of endgames.}
translate Q ChessDBEGTBResults {ChessDB: Endgame tablebase results}
translate Q TitleUnableToWriteFile {Unable to write file}
# Do NOT translate the following line - it is there to help translators only
##context Q ImportingFileNumberN {Importing file number 12 of 124}
##context E ImportingFileNumberN {Importing file number 12 of 124}
translate Q ImportingFileNumberN {Importing file number}
# Do NOT translate the following line - it is there to help translators only
##context Q er34093489fl {Importing all 124 files PGN files from the directory C:\Program Files\My Documents}
##context E er34093489fl {Importing all 124 files PGN files from the directory C:\Program Files\My Documents}
translate Q ImportingAll {Importing all}
translate Q PGNfilesFrom {PGN files from the directory}
translate Q ThereWereWarnings {WARNING: There were errors or warnings while importing those PGN files. This is not unusual, as many games found on the internet have errors in them. If you have imported a lot of games, you might wish to just ignore them. Otherwise, check the line numbers indicated carefully to find the problem. }
translate Q ThereWereNoWarnings {Note: The PGN file(s) imported without any warning messages. That is obviously good!}
# Do NOT translate the following line - it is there to help translators only
##context Q jhdgdret {Imported file 12 of 345 files, with 456 games. 323232 games have been imported now.}
##context E jhdgdret {Imported file 12 of 345 files, with 456 games. 323232 games have been imported now.}
translate Q ImportedFile {Imported file}
translate Q filesWith {files, with}
translate Q gamesImportedNow {games have been imported now}
translate Q OpenRepertoireFile {Open a repertoire file}
translate Q TitleSaveOpeningReport {ChessDB: Save opening report}
translate Q TitleErrorWritingReport {ChessDB: Error writing report}
translate Q TitleErrorStartingAnalysis {ChessDB: Error starting analysis}
translate Q StartingToImportFilename {Start to import file:}
translate Q TitleThankYouTo {Thank you to ...}
translate Q ThanksToOthers {I would like to express my thanks to the following, who have helped improve ChessDB. If I have omitted anyone, please let me know and I will correct the omission. Of course, many helped Shane Hudson with Scid, and since ChessDB is based on Scid, they have contributed too.}
translate Q ThanksTranslators {Thank you to the following have either provided translations for ChessDB, or in some other way helped to improve the translations.}
translate Q ThanksWebsite {Thank you to the following, who have translated sections of the ChessDB website to another language.  By doing this, the number of potential users will be increased, which will almost certainly lead to more developers and so an improved program.}
translate Q ThanksCode {The following have contributed code to ChessDB.}
translate Q ThanksBugReports {Unfortunately bugs are inevitable in complex software such as ChessDB. Bug reports are always useful - even if they are as small as an incorrect spelling. The following have provided bug reports in sufficient detail for the report to be useful.}
translate Q HelpChessDB1 {If anyone is able to help promote or improve ChessDB in the following ways, I would appreciate it:}
translate Q HelpChessDB2 {Submit details about ChessDB to chess related web sites. This is particularly useful if that web site uses a language other than English. It would be nice if people searching on the web found out about ChessDB, no matter what language they performed their search in.}
translate Q HelpChessDB3 {Tell others about ChessDB - it would be nice if it was as well known as ChessBase. I do this on the Internet Chess Club (ICC) some times and are surprised how many do not know what a chess database is.}
translate Q HelpChessDB4 {Write code to add new functionality, or improve upon present functionality. ChessDB uses C++ and Tcl}
translate Q HelpChessDB5 {If you are a GM or IM and are willing to put some positive comments about ChessDB on the ChessDB (or other) website, it would help. ChessDB is a LOT more than a free alternative for those who don't wish to spend their money on commercial products.}
translate Q HelpChessDB6 {Write better documentation. There are some areas of the documentation which are poor or non-existent - especially in languages other than English. Do you have any good tips that can be included in the 'Tip of the Day' which is displayed at startup?}
translate Q HelpChessDB7 {Produce binaries for Linux distributions (Redhat, Suse, Debian, Slackware etc) and preferably keep them regularly maintained. Some people may only find out about ChessDB if they find it on Linux.}
translate Q HelpChessDB8 {Maintain a binary for other UNIX and UNIX-like distibutions, such as those for AIX, Mac OS X, Solaris, IRIX, HP-UX, FreeBSD, OpenBSD, NetBSD etc. One of my projects 'atlc' (http://atlc.sourceforge.net/) has been ported to everything from a Sony Playstation 2 games console to a Cray supercomputer. I doubt ChessDB will ever be as portable, but it should be possible to produce binaries which are easy for users to install.}
translate Q HelpChessDB9 {Provide a link to the ChessDB website, http://chessdb.sourceforge.net/ on your web site. This will improve the search engine ranking of ChessDB. That will give us more users, more developers and so software with more features.}
translate Q HelpChessDB10 {Send copies of ChessDB to magazine Editors for review.}
translate Q HelpChessDB11 {Suggestions for additional features are welcome, but these are always more numerous than I have time for. Suggesions from those who contribute to ChessDB will be given higher priority. The suggestion to add a facility to import lots of PGN games at once by Mario Molinari was given higher priority (and now impleneted), since Mario has updated the Italian translation.} 
translate Q HelpChessDB12 {Update the language files. ChessDB supports many langugages, but some of the the language files have not been updated for a long time. If you, or someone you know is willing to update any of the following language files, it would be very useful:}
translate Q HelpChessDB13 {The main language file has a name somelanguage-basic.tcl (eg. swedish-basic.tcl). You can download the files from http://chessdb.cvs.sourceforge.net/chessdb/chessdb/tcl/lang/ Click on the relavant language file. Near the top you will see the following: }
translate Q HelpChessDB14 {Click on 'download', edit the file, then email the updated file to drkirkby@users.sourceforge.net}
translate Q HelpChessDB15 {Advise me of any place in which you see English text, when you expect to see that of another language. In some cases, it is difficult to convert the text, but in others it is simply that I have overlooked something. In other cases it is simply that nobody has translated the text.}
translate Q IfYouCanSuggest {If you can think of other ways in which the user base of ChessDB can be increased, please let me know at drkirkby@users.sourceforge.net.}
translate Q NoOpenDatabaseNoPlayerReport {There are 9 database slots which are used to hold a database. The current database slot is empty. Please change to a database that is not empty, using 'Switch to Database' on the 'File' menu} 
translate Q ZeroGames {The current database has 0 games in it.}
translate Q TitleZeroGames {Database has no games}
translate Q ZeroGamesNoPlayerReport {Since the database has no games in it, there are no players in the database and so a Player Report can not be generated. }
translate Q OpenDatabaseWithGames {Please open a database that has some games in it. }
translate Q NewUserNewDatabase {If you are a new user of ChessDB, you can download a database from the ChessDB web site, create one by reading in some PGN files, download games from The Week In Chess (TWIC), ICC or FICS. There are many ways to create a database, if you don't already have one. A very small sample database, having the games from the World Chess Championships, is distributed with ChessDB under the name 'wcc'.}
translate Q ZeroGamesNoFilterGraph {Since the database has no games in it, there are no players in the database and so a Filter Graph can not be generated.}
translate Q TitleYouCanHelp {How you can help ChessDB}
translate Q Czech {Czech}
translate Q Dutch {Dutch}
translate Q Finnish {Finnish}
translate Q French {French}
translate Q German {German}
translate Q Hungarian {Hungarian}
translate Q Italian {Italian}
translate Q Korean {Korean}
translate Q Norwegian {Norwegian}
translate Q Polish {Polish}
translate Q Portuguese {Portuguese}
translate Q Russian {Russian}
translate Q Serbian {Serbian}
translate Q Swedish {Swedish}
translate Q Spanish {Spanish}
translate Q Turkish {Turkish}
translate Q UnableLoadGame {Unable to load game number:}
translate Q TitleUnableLoadGame {ChessDB Error: Unable to load game}
translate Q UnableToWriteBooksmarks {Unable to write bookmarks file:}
translate Q TitleSupport {Support on ChessDB}
translate Q SupportChessDB1 {Support on ChessDB is much better than on almost any commerical software. You can easily contact the developers - not some dumb support staff, who usually know less than you. Support is free and responses to support requests are usually answered in less than 24 hours. It is quite common for a bug to be reported and a solution given in under 1 day.}
translate Q ReadTheDocumentation {Read the documentation}
translate Q SupportChessDB2 {First, before asking for support, read the documentation. In particular take a look at the tutorial at http://chessdb.sourceforge.net/tutorial/ The archives of the mailing lists at http://sourceforge.net/mailarchive/forum.php?forum=chessdb-users are helpful too.}
translate Q SoYouStillNeedSupport {Documentation not helped - still need support?}
translate Q SupportChessDB3 {Please email your support requests to}
translate Q SupportChessDB4 {Please provide the following information:}
# Do NOT translate the following line - it is there to help translators only
##context Q dfd4dfdf {The version number of ChessDB will be printed after the contents of line 'SupportChessDB5'}
##context E dfd4dfdf {The version number of ChessDB will be printed after the contents of line 'SupportChessDB5'}
translate Q SupportChessDB5 {The version of ChessDB you are using, which is}
# Do NOT translate the following line - it is there to help translators only
##context Q doererdf {The version number of Tcl/Tk will be printed after the contents of line 'SupportChessDB6'}
##context E doererdf {The version number of Tcl/Tk will be printed after the contents of line 'SupportChessDB6'}
translate Q SupportChessDB6 {The version of Tcl/Tk you are using. Tcl/Tk is needed to run ChessDB - you are using version }
translate Q SupportChessDB7 {The version of Windows you are using (95, 98, NT, 98SE, 2000, ME, XP home, XP Pro, Vista etc.} 
translate Q SupportChessDB8 {The version of UNIX or Linux you are using (Debian Linux, Slackware Linux, Solaris, FreeBSD, NetBSD etc).}
translate Q SupportChessDB9 {Whether you compiled this yourself, or if you obtained a binary from somewhere. If you compiled it yourself, report the version of gcc used. Did you build it from the code in the CVS repository? If you used a binary, report where you obtained the binary.)}
translate Q SupportChessDB10 {What steps you have taken to sort the problem out yourself.}
translate Q SupportChessDB11 {If this is a bug report and you are in a position to check this under both Windows and UNIX/Linux, it would be useful to verify if the problem exists on both systems. But this is not essential - just do it if you can easily.}
translate Q SupportChessDB12 {MOST IMPORTANT OF ALL, make the bug report or support request MEANINGFUL. Give as much detail as possible.}
translate Q SupportChessDB13 {Reports like "ChessDB does not work on my laptop" are next to useless. So are reports like "I was analysing a game and a window poped up which said Application Error". Again, that is useless, since without the exact error message (which can be saved to a log file in this case), it is difficult to know where to look for the bug.}
translate Q SupportChessDB14 {If possible send any support of bug requests in English. If sent privately to David Kirkby, please put 'ChessDB' in the title, so it is sorted into the correct email folder. This is not necessary if sending to chessdb-users@lists.sourceforge.net, which is the generally the preferred address to use.}
translate Q SupportChessDB15 {Real-time (live) support via ICC, Skype or phone}
translate Q SupportChessDB16 {If you want to have 'live' support and are a member of the Internet Chess Club (ICC), please send a 'tell' (in English) to 'g8wrb', which is the ICC handle of Dr. David Kirkby. If he is not playing a game, and has time, he will answer your questions via 'tell's.}
translate Q SupportChessDB17 {You can also use Skype (http://www.skype.com/), which allows for free international phone calls (David's Skype handle is david-kirkby) or telephone if you wish - contact David to get his telephone number.}
translate Q TitleFilterGraph {ChessDB: Filter Graph}
translate Q TitleSaveGraph {ChessDB: Save Graph}
translate Q ThankYouDavidKirkby {Thank you from David Kirkby}
translate Q ThankYouShaneHudon  {Thank you from Shane Hudson}
translate Q THANKSdotShane {The following is the contents of the file 'THANKS' which was in Scid and so have indirectly helped ChessDB. The contents for the file are unmodified, and so are therefore in English only.}
translate Q ThanksTclTelnet {Thank you to Todd Martin for developing 'tcltelnet' http://tmartin.org/tcltelnet/ which ChessDB uses to connect to chess servers using the telnet protocol.}
translate Q APoliteRequest1 {If you wish to contribute to ChessDB and become a developer, you would be most welcome. ChessDB is programmed in C++, Tcl and Tk. If you wish to create another project, based on code in ChessDB, I would respectfully ask you use another name to ChessDB - just credit Scid and ChessDB where appropiate. Using the name 'Scid' or 'ChessDB' will cause confusion amougst users, with them not knowing who to attribute bugs to.} 
translate Q APoliteRequest2 {If you create any data files (such as, but not limited to opening books, databases etc) for use with ChessDB, or derived software, I would appreciate if you keep to the spirit of free software and do not restrict their use to any particular piece of software.} 
translate Q GPL2 {ChessDB is free (but copyrighted) chess software which is licensed under the GNU General Public License (GPL). Copyrights are held by Dr. David Kirkby, Shane Hudson and others. The conditions of the GPL are listed below.}
translate Q GPL3 {Note the GPL is written in English and none of the translations in ChessDB (or anywhere else) are official translations. The Free Software Federation does not officially support any translation, for reasons explained at http://www.gnu.org/licenses/translations.html. The non-English translations here do do not count legally as substitutes for the authentic version. You can view the official English version by selecting "Language" on the "Options" menu, then selecting "English"}
translate Q NofilesRetrieved {No new files were retrieved}
translate Q NoCauseForConcern {so the fact ChessDB could not download any new files is not surprising and is therefore no cause for concern. TWIC update their database on Monday's, but varies a little, especially over holiday periods. Difference of +/- 2 from what ChessDB estimates is the latest TWIC issue, and what actually is the latest TWIC issue, are not unknown.}
translate Q Lines {Lines}
translate Q ConfigureUCIengine {Configure UCI engine}
translate Q SpecificOpening {Specific opening}
translate Q RandomLevel {Random level}
translate Q StartFromCurrentPosition {Start from current position}
translate Q FixedDepth {Fixed depth}
translate Q SecondsPerMove {Seconds per move}
translate Q TimeBonus {Time + bonus}
translate Q WhiteTime {White time (minutes + sec/move)}
translate Q BlackTime {Black time (minutes + sec/move)}
translate Q AllExercisesDone {All exercises done}
translate Q MoveOutOfBook {Move out of book}
translate Q LastBookMove {Last book move}
translate Q AnnotateSeveralGames {Annotate several games\nfrom current to :}
translate Q FindOpeningErrors {Find opening errors}
translate Q UseBook {Use book}
translate Q MultiPV {Multiple variations}
translate Q Hash {Hash memory}
translate Q OwnBook {Use engine book}
translate Q BookFile {Opening book}
translate Q AnnotateVariations {Annotate variations}
translate Q ShortAnnotations {Short annotations}
translate Q Export {Export}
translate Q BookPartiallyLoaded {Book partially loaded}
translate Q LimitCPUTime {Limit CPU time}
translate Q CPUTimeLimitSeconds {CPU time limit (s)}
translate Q DatabaseAreAlwaysSaved1 {Unlike most applications, where files are saved when you want to, in common with other chess databases (ChessBase, Chess Assistant etc), the ChessDB database (which consists of 3 files) is updated on disk during many different operations (e.g. sorting the database). Not doing so, would severly limit performance. (In fact most database applications work the same way)}
translate Q DatabaseAreAlwaysSaved2 {As such, there is no option to save a database under its current name- this happens automatically when ChessDB needs to - you have no control over when any database files are save. This means you must be especially careful to keep regular backups, in case a database becomes corrupted.}
translate Q DatabaseAreAlwaysSaved3 {For this reason, ChessDB now includes a menu item 'Backup database' on the File menu to backup the database to one of a different name. This closes an open database, then backs it up to a different name, then reopens the original again. Please use that option periodically to backup your database(s).}

translate Q BackupDatabaseNow {This will close the active database (which has}
translate Q BackupDatabaseNow1 {games in it) and back it up to a new database. The backup will be the same as the original, but will have the current date and time appended. Hence the new name will be }

translate Q BackupDatabaseNow4 {You might want to consider putting a backup onto a CD-ROM or DVD, as this will be safer than storing it on the hard disk, in case of a disk failure. If you do store the backup on your hard disk, you might consider changing the permissions so it is read-only, to reduce the chance of you removing your backup by accident.}
translate Q BackupDatabaseNow5 {Remember, a ChessDB data consists of 3 files, which have the extensions .si3 (the index file), .sg3 (the game file) and .sn3 (the name file). All 3 files are needed. If any one is missing or damaged, you will not be able to access your database. This part of ChessDB will back them all up for you.} 
translate Q BackupDatabase {ChessDB: Backup database}
translate Q SaveDatabase {ChessDB: Save database}
translate Q BackupClipbase1 {You currently have the clipbase open, which is a database that is only ever stored in memory, and never written to disk. The clipbase is intended only for temporary storage - it is not meant to be used for permanent storage. For this reason, the ChessDB database backup tool can't back this up.}
translate Q BackupClipbase2 {If you do want to save the contents of the clipbase, you should create a new database (select 'New' on the 'File' menu), then use the Database Switcher (select 'Database switcher' on the 'Windows' menu), then copy the games from the clipbase to the database you created. You could then if you wanted back up that database, but you can't back up this temporary one.}
translate Q TitleBackupClipbase {ChessDB: Clipbase can't be backed up}
translate Q NoGamesInDatabase {There are no games in the open database, so there is no point in backing it up!}
translate Q TitleNoGamesInDatabase {ChessDB error - no games in database}
translate Q TitleChooseDirectoryForBackup {Choose a directory to save}
translate Q TitleErrorCopyingFile {ChessDB Error copying file}
translate Q NotBackedUpProperly {There was an ERROR when copying a file, which means the database has NOT been backed up properly. Possible reasons for this are: disk full, no permissions to write to the location requested, bad network connection (if the location selected was on a networked drive), hard disk failure, no CD or DVD in the drive (if you were trying to write to a DVD or CD), a virus (only on Windows systems) etc}
translate Q BackupOK {The database has been backed up properly. For maximum security of your data, your backups should be on a different drive, and ideally stored in a different location. Consider putting your databases on a DVD and giving it to a friend to store at their house. Then your data is safe in the event of theft of your computer or a fire. Although it is unlikly a power supply failure which could possibly destoy all disks inside your computer, so it really is advisable to keep your backups elsewhere.}
translate Q TitleBackupOK {Back of database was successful}
translate Q OriginalDatabase {Original database:}
translate Q SendEmailUsing {Send email using}
translate Q SMTPServer {SMTP server}
translate Q SendmailProcess {sendmail process}
translate Q StripAnnotations {Strip annotations}
translate Q StripVariations  {Strip variations}
translate Q StripAnnotationsAndVariations {Strip annotations & variations}

translate Q TitleRemoveALLAnnotations {ChessDB: Remove all annotations}
translate Q RemoveALLAnnotations {Are you sure you want to remove all the annotations (but not variations) from every game in the database?}
translate Q TitleRemoveALLVariations {ChessDB: Remove all variations}
translate Q RemoveALLVariations {Are you sure you want to remove all the variations (but not annotations) from every game in the current database?}
translate Q TitleRemoveAnnotationsAndVariations {ChessDB: Remove all annotations and variations}
translate Q RemoveAnnotationsAndVariations {Are you sure you want to remove every single variation and every single annotation from all games in this current database?}
translate Q NoteThisIsSlow {Note that this operation is fairly slow. For a large database, it would be faster to export the games to a PGN file (without annotations and/or variations, then import the PGN file back into ChessDB. Try it on a small database (5000 or so games), to get some idea of the speed, before you attempt this on a large database}
translate Q NoGamesInDatabaseSoCantStrip {There are no games in the current database, so its not possible to remove any annotations or variations from this database.}
translate Q DownloadMegaDatabase1 {This will attempt to download a large database (3.5 million games at the time this version of ChessDB was built, but probably larger at a later date). The database is very large so it would be inadvisable to attempt this on a slow internet connection. Also, note the web server at http://www.chesstutor.net/ is not very fast. To make the download as trouble free as possible, the database was split into many parts. ChessDB manages the downloading of the many parts, checks each for integrity, then downloads any that are either missing or corrupted.}
translate Q DownloadMegaDatabase2 {Note that the database on the http://www.chesstutor.net/ web site is only available for download in sepparate parts, and it can ONLY be downloaded via ChessDB - it is not available for download by a normal web browser or ftp connection.}
translate Q DownloadMegaDatabase3 {Click OK to continue. You will then be told the exact number of games in the database and the exact size of the download (you get another chance to cancel if you decide its too large). If you decide to download it, you should then regularly update the database, probably using the data on the Week In Chess (TWIC) web site. Download from TWIC is automated within ChessDB.}
translate Q TitleDownloadHugeDatabase {ChessDB: Download a huge database}
translate Q TitleChooseDirectoryForDatabaseToBeSaved {Choose a directory for the database to be saved}
translate Q TitleProblemAccessingWebSite {ChessDB Problem accessing web site}
translate Q ProblemAccessingWebSite {There was a problem with the download from this web site. Please try another (http://chessd.sourceforge.net/ rather than http://www.chesstutor.net/ or the other way, depending on which one is presenting you problems). }
translate Q IfYouCantResolveError {If you can't resolve this problem, please email chessdb-users@lists.sourceforge.net and give the *EXACT* error message, as well as describe what you were doing when it occured, and anything you think might just be relavant.}
translate Q TitleSizeMismatchForMegadatabase {ChessDB Number of games differ}
translate Q SizeMismatchForMegadatabase1 {The remote server has a database and has reports the number of games in that database. You have a file locally which reports the number of games in the database you have tried to download before. Those two numbers do not agree. Cleary the databases are different, and so there is no point in mixing parts between them, as it would give a totally useless collection of files}
translate Q SizeMismatchForMegadatabase2 {The file on the remote server is}
translate Q SizeMismatchForMegadatabase3 {The name of the remote database is}
translate Q SizeMismatchForMegadatabase4 {The number of games in that remote database, reported in the above file, is}
translate Q SizeMismatchForMegadatabase5 {The local file is}
translate Q SizeMismatchForMegadatabase6 {The number of games expected in the database locally is}
translate Q SizeMismatchForMegadatabase7 {The name of the database expected locally is}
translate Q TitleErrorWritingFile {ChessDB: Error writing file}
translate Q ErrorWritingFile {There was a problem when ChessDB tried to write to a file. }
translate Q DownloadDatabaseName {This will download the database called}
translate Q NumberOfGames {The number of games in the database is}
translate Q SizeCompressed {The database is stored on the remote server in a compressed form to reduce the time to download. The size on the remote server (and hence what you need to download) is}
translate Q SizeUncompressed {Once downloaded the database will be uncompressed and take up more disk space. The disk space in normal use will be}
translate Q ContinueWithDownloadQ {Are you sure you want to continue with this large download?}
translate Q AutoSelectWinboardUCI {Autodetect Winboard/UCI}
translate Q SummaryEngineProtocols {The vast majority of chess engines use one of two protocols - the Winboard protocol deveoped by Tim Mann or the UCI protocol developed by ChessBase. Commerical engines tend to use UCI more than Winboard, but both protocols are in common use. Some engines can work with either protocol, but you will get maximum benifit in ChessDB if you use the UCI protocol. Some obscure engines don't follow the protocols very well, so may not work.}
translate Q CurrentNoAutodetect {Currently ChessDB can not automatically select the right protocol (Winboard or UCI), so you will have to set it manually yourself. An autodetection feature will be added some time.}
translate Q CommonEngineProtocols {Common engines and the protocols they used are:  Beowulf (Winboard), Chessdblet (Winboard), Crafty (Winboard), Fruit (UCI), Gandalf (UCI), Gnuchess (Winboard), Hiarcs (UCI), Jupiter (Winboard), Phalanx (Winboard), Rybka (UCI), Ruffian (UCI and Winboard), Scidlet (Winboard), Shredder (UCI and Winboard), Spike (UCI and Winboard), The Barron (Winboard), Toga (UCI), Yace (Winboard and UCI). Zappa (Winboard and UCI). If you are not sure what your engine is, try both - it will not do any harm.}
translate Q AutodetectProtocol {ChessDB will try to determine the type of chess engine you have. It will first try the UCI protocol and if the engine appears to support that, ChessDB will use that. Some engines support both UCI and Winboard, so you might find such an engine works better if you use the Winboard protocol. However, in general UCI is preferable, as UCI engines can show multiple lines of analysis, not the one of UCI enginess.} 
translate Q ConfigureChessEngine {ChessDB: Configure a UCI or Winboard analysis engine}
translate Q ChessDBFree {ChessDB - a totally free chess database}
translate Q UCIProtocol {Using UCI protocol}
translate Q WinboardProtocol {Using Winboard protocol}
translate Q ProtocolNotSet {Protocol not set}
translate Q AnEngineAlreadyRunning {An engine is already running. Please stop the engine before trying to configure this one}
translate Q ErrorStartingUCIChessEngine {Error starting UCI chess engine. Check the file permissions, engine type (UCI or Winboard), correct filename and path. Unable to start the program:}
translate Q TitleErrorStartingUCIChessEngine {Error starting UCI chess engine}
translate Q TitleNotUCIEngine {Not a UCI chess engine}
translate Q NotUCIEngine {The engine does not appear to be a UCI engine, as it did not reply 'uciok' when sent the UCI command 'uci'. Try configuring it as a Winboard engine, unless you are sure it is a UCI engine.}
translate Q TitleEPDFieldStripped {ChessDB: EPD field stripped}
translate Q EPDFieldStripped {ChessDB found and stripped an EPD field named}
translate Q TitleTooManyEPDFilesOpen {Too many EPD files open}
translate Q TooManyEPDFilesOpen {You have too many EPD files open, so please close one before opening anoher. The maximum number you can have open at any time is}
translate Q TitleEPDFileError {ChessDB: EPD file error}
translate Q StripEPDField {Strip out EPD field}
translate Q SetBookpath {Set path to opening books}
translate Q FindDeepestGamePosition {Find Deepest game position}
translate Q NextPositionInFile {Next position in file}
translate Q AnnotatePositions {Annotate positions}
translate Q ChooseBookForAnalysis {Choose an opening book for analysis}
translate Q CorruptedSegment {A segment of the file was corrupted and will be downloaded again. The segment was:}
translate Q DatabaseDownloadedOK {The database was downloaded properly. To keep the database up to date you may want to download games from TWIC regularly, which you can do from the Tools menu in ChessDB. (The TWIC web site is updated about once/week). When produced, the database you have downloaded had all the games from TWIC at that time, so there is no need to update games from TWIC that are earlier than issue number}
translate Q Notes {Notes}
translate Q EPDFileAltered {This EPD file has been altered; do you want to save it?}
translate Q CloseWithoutSaving {Close without saving}
translate Q SaveChanges {Save changes}
translate Q CreateEPDFile {Create an EPD file}
translate Q OpenEPDFile {Open an EPD file}
translate Q Copy {Copy}
translate Q Paste {Paste}
translate Q SelectAll {Select All}
translate Q Cut {Cut}
translate Q PreviousPositionInFile {Previous position in file}
translate Q PasteAnalysis {Paste analysis}
translate Q EPDFilesHelp {EPD files help}
translate Q GeneralIndex {General index}
translate Q RemoveEPDField {Enter the name of the EPD field you want removed from all positions in this EPD file:}
translate Q TitleFirewallNotes {Using a firewall}
translate Q FirewallNotes0 {Firewalls and ChessDB}
translate Q FirewallNotes1 {If you use a firewall on your computer, you will need to configure the firewall to allow outgoing TCP connections to the following domains in order to use all of ChessDB's features. }
translate Q FirewallNotes2 {FICS            freechess.org}
translate Q FirewallNotes3 {ICC             chessclub.com}
translate Q FirewallNotes4 {Chesstutor.net  chesstutor.net}
translate Q FirewallNotes5 {TWIC            chesscentre.net}
translate Q FirewallNotes6 {Bookup          bookup.com }
translate Q FirewallNotes7 {Sourceforge     sourceforge.net }
translate Q FirewallNotes8 {For the two chess servers, ICC and FICS, opening port either port 23 or 5000 will normally allow you access although it depends. For the web sites (Chesstutor.net, Bookup, TWIC and Sourceforge) you only need to open the standard port for HTTP communications (port 80).}
translate Q FirewallNotes9 {Note, that if you use a hardware based firewall, these don't usually care what application is using a particular port, so if you can access these sites with your browser and chess server software, you will probably need to make no changes to allow ChessDB to be used. (That is the case in July 2007 when this was wrote, but computer technology will no doubt change, so that may not be so later on.)}
translate Q FirewallNotes10 {However, many software firewalls, such as those built into Microsoft Windows, Norton etc, monitor activity by individual programs. So just because you can access these sites with your browser or normal chess server software, does not mean that ChessDB will have access too. It may be necessary to configure your software firewall to allow ChessDB access to these sites.}
translate Q FirewallNotes11 {As with any problem in ChessDB, if you get stuck, please e-mail Chessdb-users@lists.sourceforge.net}
translate Q FirewallNotes12 {Opening the correct port for a firewall}
translate Q ChessDBNumberDownloadOptions0 {When using ChessDB it is very useful to have access to a large collection of games, to make a 'reference' database. This allows you to see how other players normally play in a specific position. You can buy such a database from ChessBase (e.g. there Megabase 2007), or you can download one. A database bought from ChessBase will have annotations, player photos and other items that you can not legally get from simply downloading a database.}
translate Q ChessDBNumberDownloadOptions1 {ChessDB has a number of download options, which allows ChessDB to download games from the internet. This is one area of ChessDB where the authors have very little control, as external sites may go offline at any time. The options are:}
translate Q ChessDBNumberDownloadOptions2 {ICC (Internet Chess Club) allows you to download games from the internet chess club. They can be your games, or those of others. ICC limits downloads to 100 games in quick succession, so this is not a way to get a very large database}
translate Q ChessDBNumberDownloadOptions3 {FICS (Free Internet Chess Server) is just like ICC, but is free. I'm not sure what limits FICS put on the download of games.}
translate Q ChessDBNumberDownloadOptions4 {TWIC (The Week in Chess). This is no doubt the most well known site, which has collections of games played by strong players that are updated weekly}
translate Q ChessDBNumberDownloadOptions5 {http://chessdb.sourceforge.net/ This is a large database which was uploaded to the Sourceforge web server by Dr. David Kirkby. It will be occassionally updated, but there is no plan to make regular updates of it.}
translate Q ChessDBNumberDownloadOptions6 {http://www.chesstutor.net/ has the same database as at http://chessdb.sourceforge.net/, but is on a slower line. However, is sourceforrge complain about the amount of disk space the database there takes up, downloading it from http://www.chesstutor.net/ may be your only option.}
translate Q ChessDBNumberDownloadOptions7 {http://www.bookup.com/ Bookup provides a list of 500 PGN files for download, sorted by ECO code, so there is a file called A00.pgn, another A01.pgn ...E99.pgn. I don't know how often (if at all) these are updated.}
translate Q ChessDBNumberDownloadOptions8 {Be aware when you download games from mulitple site, there will be duplicates, so these must be removed.}
translate Q TitleDownloadNotes {ChessDB: Notes about downloading games}
translate Q ErrorReadingSearchOptionsFile {Unable to open or read SearchOptions file:}
translate Q TitleErrorReadingFile {ChessDB: Error reading file}
translate Q ComparingStatisticalSignificance1 {Right-click on a pair of moves to compare them statistically}
translate Q ComparingStatisticalSignificance2 {Statistical comparision between}
translate Q TitleTreeGraph {ChessDB: Tree Graph}
translate Q ScoresIdenticalInDatabase {The scores of the moves}
translate Q and {and}
translate Q ScoresIdenticalInDatabase2 {are identical in this database}
translate Q CantRejectHypothesis {but the difference is NOT statistically significant.}
translate Q Accept1pc {and is highly statistically significant with a p-value of less than 0.01.}
translate Q Accept5pc {and is statistically significant at the 5% significance level}
translate Q PleaseRightClickMove1 {Please right-click on any two moves you would like to compare}
translate Q PleaseRightClickMove2 {selected. Please right-click the move you wish to compare with}
translate Q MakeNoComparisons {Therefore you should NOT assume that one move is better than the other}
translate Q ABetterMove1 {Therefore}
translate Q ABetterMove2 {is PROBABLY no worst (and quite possibly better) than}
translate Q ABetterMove3 {is ALMOST CERTAINLY no worse (and quite possibly better) than}
translate Q ABetterMove4 {If the database is of high quality. If the quality of the database is poor, then ignore this.}
translate Q StatisticalSignificance {Statistical significance test results}
translate Q TitleChooseDatabaseIcon {ChessDB: Choose database icon}
translate Q ChangeDatabaseIcon {Change icon...}
translate Q TitleFilterStatistics {ChessDB: Filter Statistics}
translate Q ErrorSavingFile {ChessDB was unable to save the file:} 
translate Q TitleSaveTextFile {ChessDB: Save text file}
translate Q TitleSavePGNFile {ChessDB: Save PGNfile}
translate Q TitleSaveCrosstable {ChessDB: Save Crosstable}
translate Q TitleSaveCrosstableHTML {ChessDB: Save Crosstable as HTML}
translate Q ClearAllSymbolsForThisMove {Clear all annotation symbols for this move} 
translate Q ClearThisComment {Clear this comment}
translate Q RevertToStoreComment {Revert to the stored comment}
translate Q CloseTheCommentEditorWindow {Close the comment editor window}
translate Q StoreCommentInGame {Store this comment in the game}
translate Q ErrorCoordinatesListMustBeEven {Error: coordinates list must have an even length}
translate Q UnreconisedDataOptions {Unrecognised graph data options:}
translate Q NoSuchGraphOption {No such graph option:}
translate Q TitleChessDBVersionError {ChessDB: Version Error}
translate Q TitleSoundFiles {ChessDB: Sound Files}
translate Q TitleUnableToCreateBase {ChessDB: Unable to create database}
translate Q TitleSpellcheckFileLoaded {ChessDB: Spellcheck file loaded}
translate Q TitleNoGames {ChessDB: No games}
translate Q TitleSpellcheckError {ChessDB: Spellcheck error}
translate Q TitleSpellcheckResults {ChessDB: Spellcheck results}
translate Q TitleEmptyEmailAddress {ChessDB: Empty email address}
translate Q TitleErrorSendingEmail {ChessDB: Error sending email}
translate Q StandardStartPosition {Standard start position}
translate Q CurrentBoardPosition {Current board position}
translate Q TitleNoDatabaseOpen {ChessDB: No database open}
translate Q TitleEmptyDatabase {ChessDB: Empty database}
translate Q TitleFilterEmpty {ChessDB: Filter empty}
translate Q TitleReallyDeleteOpponent {Really delete opponent}
translate Q NoDatabaseOpen {No database is open; open or create one first.}
translate Q TitleOpenSpellcheckFile {ChessDB: Open Spellcheck file}
translate Q TitleErrorProducingReport {ChessDB: Errors producing report}
translate Q TitleUnableToRunXDVI {Unable to run \"xdvi\"}
translate Q TitleUnableToRunDVIPS {Unable to run \"dvips\"}
translate Q UnableToRunDVIPStoConvert {Unable to run \"dvips\" to convert the opening report to PostScript.}
translate Q UnableToRunXDVItoView {Unable to run \"xdvi\" to view the opening report.}
translate Q ErrorsRunningLatex {Errors running LaTeX on the file:}
translate Q SeeTheFollowingLogFile {See the following log file for details:}
translate Q TitleGenerateOpeningReport {ChessDB: Generating opening report}
translate Q SearchingDatabaseForGames {Searching the database for games to include in the report}
translate Q GereratingReportInformation {Generating report information}
translate Q TitleErrorWritingOpeningReport {ChessDB: Error writing opening report}
translate Q TitleErrorWritingPlayerReport {ChessDB: Error writing player report}
translate Q NoGamesInDatabaseToDelete {There are no games in this database to delete.}
translate Q SpellcheckWindowOpen {The spellcheck window is already open; close it first.}
translate Q MakeCorrections {Make spelling corrections}
translate Q MakingCorrectionsWait {ChessDB is making the spelling corrections.\nPlease wait...}
translate Q CouldNotReadSpellcheckFile {ChessDB could not correctly read the spellcheck file you selected:}
translate Q players {players}
translate Q events {events}
translate Q rounds {rounds}
translate Q sites {sites}
translate Q InvalidFEN {ChessDB: Invalid FEN}
translate Q MustGiveEmail {You must specify an email address}
translate Q EnterSubjectForMessage {Enter the subject for each message}
translate Q EnterOpponentsEmail {Enter the opponent's email address}
translate Q EnterOpponentsName {Enter the opponent's name}
translate Q EnterOpponetsGameNumbers {Enter the opponent's game numbers, separated by spaces}
translate Q EnterClosingText {Enter the closing text for each message}
translate Q DoYouWantToDelete {Do you really want to delete this opponent?}
translate Q TitleInvalidGameNumber {ChessDB: Invalid Game number}
translate Q GameListContainsInvalidGameNum {The games list contains an invalid game number:}
translate Q TheLastGame {The last game in this database is game number}
translate Q NoFavoriteReportPositons {You have no favorite report positions}
translate Q SelectReportFileFormat {Select the report file format:}
translate Q FullOpeningReport {Full (includes theory table)}
translate Q CompactOpeningReport {Compact (no theory table)}
translate Q TheoryOpeningReport {Theory table only}
translate Q SelectReportType {Select the report type:}
translate Q PlainTextTXT {Plain text (.txt)}
translate Q ChooseReportFolder {ChessDB: Choose Report Folder}
translate Q SaveReportsInFolder {Save reports in the folder:}
translate Q TitleDatabaseReadOnly {ChessDB: Database is Read-only}
translate Q TrainingModeResultsHidden {(Training mode; results are hidden)}
translate Q TablebaseTextIMPORTANT1 {Side    Longest    %     %     %\n} 
translate Q TablebaseTextIMPORTANT2  {to move   mate    Win  Draw  Loss\n} 
translate Q SearchingForExtraPGNTags {Searching for extra PGN tags...}
translate Q TitleSearchForExtraPGNTags {ChessDB: Search for extra PGN tags}
translate Q NoTwinsFound {ChessDB did not find any twin games.}
translate Q FoundOneTwin {ChessDB found just one single twin game in this database and set the delete flag for it.}
translate Q ChessDBFound {ChessDB found}
translate Q TwinGameInDatabase {twin games in this database and set their delete flags.}
translate Q NoteDeletedLater {Please note games don't actually get totally deleted until the database has been compacted - before a database is compacted, it is possible to undelete games.}
translate Q BeAwareTheTwinGameDetection {Please be aware that the twin game detection is not 100% flawless. If the entire source of data were PGN file(s) created entirely automatically by a chess server (such as ICC or FICS), then the PGNs would be identical and so ChessDB should have no problem finding duplicate games. But when the PGN file(s) were created by humans, they tend to have all sorts of errors, which makes finding all the duplicates rather difficult. Two sorts of problems can occur; Firstly ChessDB can find two games it determines are duplicates, but they are not duplicates. Secondly ChessDB can fail to find one or more duplicated game.}
translate Q ForMoreInfoOnTwins {For more information about some of the problems in finding twin games, see: http://chessdb.sourceforge.net/tutorial/t_maint_delete.php}
translate Q TitleTWinGameChecker {ChessDB: Twin game checker}
translate Q ThereAreNoGamesSoNoTwins {There are no games in the current database. Since there are no games, there are obviously no twin games.}
translate Q NoTwinDetected {No twin was detected for this game.}
translate Q ToShowTwinsUsingThisWindow {To show twins using this window, you must first use the 'Delete twin games..' function. You can do this by clicking the button below if you have not already used the function.}
translate Q TitleTwinGameResults {ChessDB: Twin game results}
translate Q OneToFlip {("1" to flip; "u" undeletes both)}
translate Q TwoToFlip {("2" to flip; "u" undeletes both)}
translate Q GamesInTournament {Games in tournament:}
translate Q TitleNoUnusedNames {ChessDB: No unused names}
translate Q TitleNoUnusedGames {ChessDB: No unused games}
translate Q CompactingTheNameFile {Compacting the name file...}
translate Q CompactingTheGameFile {Compacting the game file...}
translate Q TitleErrorCompactingGameFile {ChessDB: Error compacting game file}
translate Q TitleErrorCompactingNameFile {ChessDB: Error compacting name file}
translate Q SortingDatabase {Sorting the database}
translate Q YouAreAdvisedToClose {There is a bug in ChessDB which means it can crash if there is an error opening one of the important database files (the .si3, .sn3 or .sg3 files). You are advised to close ChessDB and reopen it.}
translate Q StoringResultsOfSort {Storing sorted data ...}
translate Q ScoresBetterThan {scores better (for white) than}
translate Q YouMustCompareDifferentMoves {You must select two different moves}
translate Q SelectAMoveToCompare {Select a move to compare with}
translate Q YouCanNowSelectAnotherPairOfMoves {(You can now select another pair of moves if you wish)} 
translate Q InterestingNewFeature {There is an interesting new feature which was added to the Tree Window in ChessDB 3.6.19-beta-1. That basic Tree Window which exists in Scid, ChessBase and earlier versions of ChessDB show the score for white for each of the moves. It is tempting to think one move is better than another move if the score is higher. ChessDB can now run a chi-squared statistical test and determine if the difference in score between any two moves is statistically significant, or if it is likely to be due to chance.}
translate Q WhiteWins {White wins:}
translate Q BlackWins {Black wins:}
translate Q Draws {Draws:}
translate Q TitleConfigureWinboardOrUCIEngine {ChessDB: Configure a Winboard or UCI engine}
translate Q EngineProtocolNotDetermine {Autodetect of Winboard/UCI failed}
translate Q TitleAutodDetectNotImplemented {ChessDB: Autodetection is not implemented}
translate Q MathematicallyMinded {For the mathematically minded, the p-value is}
translate Q ThanksRayKoopman {Thank you to Ray Koopman who suggested a simple numerical approximation to determine the p-value from the chi-squared distibution, which is used to calculate statistical significance in the tree window.}
translate Q Many64bitEngines {Some of the chess engines which come with ChessDB are 64-bit and will not work on older 32-bit CPUs or on 32-bit versions of Windows.}
translate Q TitleHTTPBError {ChessDB: HTTP Error}
translate Q TitleDownloadComplete {ChessDB: Download completed}
translate Q DownloadOfDatabaseComplete {ChessDB has downloaded the database name}
translate Q DownloadOfDatabaseComplete2 {for you. Like all ChessDB databases, there are 3 files for this database, which are all in the directory: }
translate Q IntermediateFilesBig {The intermediate files created would have been large and quite numerous. It is generally best to let ChessDB delete these files now, to save disk space and you difficulty in deleting the right files. If you want to delete the files manually yourself, hit Cancel and the files will not be deleted.}
translate Q IntermediateFilesBig2 {The intermediate files created will be taking up a lot of unnecessary disk space (approximately}
translate Q IntermediateFilesBig3 {It is generally best to let ChessDB delete these files now, to save disk space. If you want to delete the files manually yourself, hit Cancel and the files will not be deleted - but only do this if you have a good reason to keep the files.}
translate Q TitelBigIntermediateFiles {ChessDB: Large intermediate files}
translate Q LetChessDBDelete {Let ChessDB delete all these files for you?}
translate Q TheFilesWillNotBeDelete {The files from the download have not been deleted. You should delete them manually. There will be lots of files with names like the following}
translate Q PlusUncompressedVersions {In addition to those Zip files, there will be uncompresed versions too:}
translate Q NeedTemporarySpace {During the download, ChessDB will need more space, although this will be recovered once the download is completed. The amount of temporary space needed is about}
translate Q NeedTemporarySpace2 {After the database is downloaded and the temporary files are removed, the database will take up CONSIDERABLY less space than the same number of games would do if stored in a PGN file.}
translate Q EnjoyYourDatabase {Enjoy using your new database. A large database is particularly useful when used with the Tree Window in ChessDB. You can investigate if one move is more effective than another and check the statistical significance of the results from the database.}
translate Q TitleFilesRemainUndeleted {ChessDB: Files remain undeleted}
translate Q TitleAllFilesPresent {ChessDB: Files already on disk}
translate Q AllFilesProbablyOK {All 3 of the database files are present in the directory you selected and all 3 have exactly the expected length, which are:} 
translate Q AllFilesProbablyOK2 {Therefore you can be ALMOST CERTAIN you do NOT need to download the database again, which is good, as the files are large.}
translate Q AllFilesProbablyOK3 {However, if you have tried to use the database and can't access it properly, it is *remotely* possible that one of the 3 files is corrupted. I might guess the chances are one in 100 or a little less}
translate Q AllFilesProbablyOK4 {An MD5 checksum is like a fingerprint for a file, so if the MD5 checksum of your ChessDB database files are correct, there is only a one in 340282366920938463463374607431768211456 chance the files are damaged (i.e. it is a LOT better than just relying on file size). Therefore verifying the MD5 checksums is useful if you have reason to believe a file is corrupted.}
translate Q AllFilesProbablyOK5 {ChessDB can not currently calculate the MD5 checksums of the files on your disk, but it can tell you what they should be. You can then verify if the checksums are correct using freely available software. The MD5 checksums of the 3 database files should be:}
translate Q AllFilesProbablyOK6 {The MD5 checksums of all the files that were used to make the database can be found in the file}
translate Q bytes {bytes}
translate Q TitleDownloadDatabaseNow {ChessDB: Confirm downloading}
translate Q TitleEmptyEPDField {ChessDB: Error - Empty EDP field}
translate Q EmptyEPDField {If you wish ChessDB to remove an EPD field for you, you must enter it the name of the field you want removed.}
translate Q NoSuchEPDField {ChessDB did not find any line with the EPD field named}
translate Q TitleNoEPDFieldsToSort {ChessDB: No EPD fields to sort}
translate Q NoEPDFiledsToSort {There are no EPD fields (typically acd for 'analysis count', ce for 'centipawn evaluation' etc) in the current EPD file, so EPD fields can not be sorted.}
translate Q TitleUnzipFailed {ChessDB: Error decompressing file}
translate Q UnzipFailed {There was a failure when trying to decompress the following file using  unzip:} 
translate Q UnzipFailed2 {This has been known to happen if the file returned from the web server is not a Zip file, but instead is HTML or similar. It would also happen if you run out of disk space, so the Zip file was not written properly. Whatever the reason may be, the decompression failed. Please see the rest of the error message. If the file has been saved to your disk, check if you can unzip it with another program. If it is HTML or text, please email the contents to david.kirkby@onetel.net, so it can be debugged}
translate Q DownloadMegaDatabase5 {There are two web sites with the database - http://chessdb.sourceforge.net/ and http://www.chesstutor.net/. It is suggested you use the Sourceforge site (#1) but the Chesstutor.net site may be used if the database is unavailable on Sourceforge.}
translate Q NoteSuperset {Please note that the databases are a subset of the very largest (over 3.5 million games). If you download the 3.5 million game database, there is no point in downloading a smaller one (e.g. 100,000) too, as the 3.5 million game gamedatabase has all the games of the 100,000 database, but with an additional 3.4 million games. Download the largest you can, given the quality of your internet connection. ChessDB should resume where it left off, should the connection become disconnected.}
translate Q OpeningRepertoirFile {ChessDB opening repertoir file}
translate Q AddingEloRatings {Adding Elo ratings}
translate Q BothWinboardAndUCI {ChessDB supports both UCI and Winboard engines.}
#translate Q Opening repertoire file {ChessDB opening repertoire file}
translate Q ThereoreYouNeedSpace {Therefore you should have }   
translate Q ThereoreYouNeedSpace2 {free disk space before continuing.}
translate Q DownloadConsoleMessages {Database download - console messages}
translate Q TitleDownloadConsoleMessages {ChessDB: Console messages while downloading}
translate Q WillDownloadFrom {The database will be downloaded from:}
translate Q AlthoughRedirect {Although the web server may redirect ChessDB to another location} 
translate Q NameOfDatabase {The name of the database to be downloaded is:}
translate Q GameFileParts {The game file (.sg3) file consists of the following number of parts:}
translate Q IndexFileParts {The index file (.si3) file consists of the following number of parts:}
translate Q NameFileParts {The name file (.sn3) file consists of the following number of parts:}
translate Q CancelDownload {Cancel download}
translate Q BigDatabases {Databases with 100,000 or >3.5 million games}
translate Q BigDatabases2 {Two databases (one of 100,000 games, and a second with over 3.5 million games) have been placed on the web at a couple of sites (Sourceforge and Chesstutor.net). These are refered to as site #1 and #2 on the Download menu. It would be useful to download one of these - preferably the larger one, but if not the smaller one. The largest is several hundred MB in size - if you attempt to download this, it will let you know the exact size and number of games and give you plenty of chances to exit. Should you start the download, you can cancel and resume at a later date.}
translate Q TitleReallyQuitDownload {ChessDB: Quit download?}
translate Q ReallyQuitDownload {Do you really wish to cancel the download?}
translate Q ReallyQuitDownload2 {If you do quit now, you can resume at a later date, without needing to download all the same files again, as long as you leave any temporary files that are downloaded in the directory}
translate Q NoMD5ProgFound1 {ChessDB was unable to find an executable program called 'md5' or 'md5sum', which would be used to compute a checksum to verify the integrity of files.}
translate Q NoMD5ProgFound2 {While this does not prevent the any part of the database  being downloaded, it does mean it will be impossible for ChessDB their integrity properly. ChessDB will verify the file sizes are correct, but that is the limit of its capabilities unless you install a program able to calculate the md5 checksums of a file. }
translate Q NoMD5ProgFound3 {A program md5.exe is included with the Windows binary distibution of ChessDB and a working MD5 could easily be installed on any UNIX or Linux system.}

translate Q TitleNoMD5ProgFound {ChessDB: md5 or md5sum}
translate Q ToggleEngineAnalysis {Toggle analysis engine on/off}
translate Q StartAnalysisEngine {Start the analysis engine}
translate Q StopAnalysisEngine {Stop the analysis engine - useful on a laptop, to save power.}
translate Q EnginePlaysBlackAndWhite {Set the chess engine to move first for one side, then the other}
translate Q StopEnginePlayingBoth {Stop the engine playing both sides. Put engine into analysis mode.}
translate Q NotValidFENPosition {The current text selection is not a valid chess position in FEN notation.}
translate Q TooManyWhitePieces {There are too many white pieces!}
translate Q TooManyWhitePawns {There are too many white pawns!}
translate Q TooManyBlackPieces {There are too many black pieces!}
translate Q TooManyBlackPawns {There are too many pawns!}
translate Q MustBeWhiteKing {There must be one white king.}
translate Q MustBeBlackKing {There must be one black king.}
translate Q TitleSetStartBoard {ChessDB: Set start board}
translate Q CurrentTextSelectionMT {The current text selection is empty.}
translate Q ToPasteStartBoard1 {To paste the start board, select some text that}
translate Q ToPasteStartBoard2 {containst a position in FEN notation.}
translate Q TheSelectedText {The selected text is:}
translate Q FENExplanation1 {Forsyth-Edwards Notation (FEN) is a standard notation for}
translate Q FENExplanation2 {describing a particular board position. It includes information} 
translate Q FENExplanation3 {on castling, en-passent captures and the side to move.}
translate Q FENExplanation4 {As an example, the FEN representation of the standard starting position is:}
translate Q FENExplanation5 {rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1}
translate Q InvalidBoard {Invalid board.}
translate Q InvalidPiece {Invalid piece.}
translate Q TitleAddElo {ChessDB: Add ELO ratings}
translate Q NoGameInFilter {There are no games in the filter, so no Elo ratings can be added.}
translate Q NoRatingsAdded {ChessDB did not add any Elo ratings. Perhaps all the games have them, or perhaps the players are not in ChessDB's database. The ratings file is maintained by Franz Nagl e4c5@aon.at and is stored at http://members.aon.at/schachverein.steyr/ You should obtain the latest copy. At the time this was written, Franz's latest version had the latest FIDE-ratings from January 2007.}
# PLEASE TRANSLATE
translate Q TitleDownloadDatabase {ChessDB: Download a database}
# PLEASE TRANSLATE
translate Q DownloadMegaDatabase4 {This will attempt to download a database from either http://chessdb.sourceforge.net/ (site #1) or http://www.chesstutor.net/ (site #2). The Sourceforge site (#1) is the faster of the two. To make the download as trouble free as possible, the database was split into multiple parts.}
# PLEASE TRANSLATE
translate Q DownloadMegaDatabase6 {Click OK to continue. You will then be told the exact number of games in the database and the size. You can then decide whether to proceed or not.}
# PLEASE TRANSLATE
translate Q TheresOneGameNoTwins {There is only one game in the current database, so there are obviously no twin games.}
# PLEASE TRANSLATE
translate Q TitleTheresOneGameNoTwins {ChessDB: Only one game, so no twins}
# PLEASE TRANSLATE
translate Q TooFewGames {There are too few games for ChessDB to do any useful tests of significance. Therefore the p-value will not be calculated.}
# PLEASE TRANSLATE
translate Q PleaseWaitForMD5 {ChessDB will now verify the MD5 checksums of the 3 database files, to verify their integrity. This may take a minute on two.}
# PLEASE TRANSLATE
translate Q MD5rOK1 {The database has been successfully downloaded, so it can be used in ChessDB.}
# PLEASE TRANSLATE
translate Q MD5rOK2 {Since large downloads are prone to corruption, ChessDB has checked the downloaded files for integrity using the cryptographic strength MD5 algorithm. You can be more than 99.9999999999999999999999999999999999991 % sure that all 3 database files have been downloaded without error.}
# PLEASE TRANSLATE
translate Q TitleMD5rOK {ChessDB: Succesful download}
# PLEASE TRANSLATE
translate Q DownloadLarger {Since you only downloaded the 100,000 game database, and not the larger one with at least 3.5 million games, you might want to consider downloading the larger database later. Although 100,000 games might appear to be a lot, these cover a very wide range of openings, so you will soon find there are very few games with the exact same positions you want to investigate - especially if the move you are interested in is not a main line. You will soon find out the statistical significance tests, (which are a feature unique to ChessDB), will work much better with a larger database.}
# PLEASE TRANSLATE
translate Q GameFileCorrupted  {The MD5 checksum of the game file}
# PLEASE TRANSLATE
translate Q NameFileCorrupted  {The MD5 checksum of the name file}
# PLEASE TRANSLATE
translate Q IndexFileCorrupted {The MD5 checksum of the index file}
# PLEASE TRANSLATE
translate Q FileCorrupted1 {did not match the MD5 checksum expected. If you have just downloaded the file, then the file is corrupted.} 
# PLEASE TRANSLATE
translate Q FileCorrupted2 {If however you downloaded it some time ago and opened the database in ChessDB, then this is to be expected, since any changes to the database files will change their checksums.}
# PLEASE TRANSLATE
translate Q TitlePossibleCorruptedFile {ChessDB: Possible file corruption}
# PLEASE TRANSLATE
translate Q ChecksumExpected {The MD5 checksum expected is:}
# PLEASE TRANSLATE
translate Q ChecksumOfFile {The MD5 checksum found was:}
}


