# Copyright (C) Dr. David Kirkby 2006-2007 
# ChessDB http://chessdb.sourceforge.net/

# ChessDB is a Chess Database based on one called 'Scid'

# To avoid any confusion, this program is called ChessDB rather than 
# Scid. It uses a lot of Scid code
# http://scid.sourceforge.net/, but I don't want Shane Hudson, 
# (the author of Scid) to be responsible for any bugs in ChessDB. 

# Download games from http://www.chesstutor.net/

# A file called '$databasename.database_info.txt' will be stored on the web\
  site and indicate
# information about the database. The URL will be different for Sourceforge 
# and http://www.chesstutor.net/, the procedure will take as an 
# argument the base url. 

proc ::tools::DownloadHugeDatabase {baseurl databasename} {
    puts $baseurl
    puts $databasename
    set deletethese ""
    if { $databasename == "huge" } {
    set answer [tk_messageBox -type okcancel -icon question -title\
      [tr TitleDownloadHugeDatabase] -message\
      "[tr DownloadMegaDatabase1]\n\n[tr DownloadMegaDatabase2]\n\n[tr\
      DownloadMegaDatabase3]"]
    } {
    set answer [tk_messageBox -type okcancel -icon question -title\
      [tr TitleDownloadDatabase ] -message [tr DownloadMegaDatabase4]]
    }
    switch -- $answer {
    ok { }
    cancel {
	    return
	}
    }

    # Find where to store the database
    if {$::windowsOS} {
       set initialdir [file join $::chessdbExeDir databases ]
       set initialdir [file nativename $initialdir]
    } else {
       set initialdir "/"
    }
    set dirname [tk_chooseDirectory -initialdir $initialdir -title\
      [tr TitleChooseDirectoryForDatabaseToBeSaved] -mustexist 1]
    set dirname [file nativename $dirname]
    if {$dirname == ""} {
	return
    }

    # Look on the local disk for a file '$databasename.database_info.txt'\
      which may exist. If
    # so it will list i) Games in database ii) File size iii) File name
    # of the database that is either completed locally, or 
    # partially completed. 

    # The file will be called 1000.database_info.txt, 10000.database_info.txt,\
      100000.database_info.txt, 1000000.database_info.txt
    # or huge.database_info.txt

    # Clearly this file will not exist first time this is run. 

    set dbinfofile "$databasename.database_info.txt"
    puts "dbinfofile=$dbinfofile"
    set file_on_disk [file join $dirname $dbinfofile]
    set file_on_disk [file nativename $file_on_disk]

    set md5sumfile  "$databasename.md5sum.txt"
    set md5sumfile [file join $dirname $dbinfofile]
    set md5sumfile [file nativename $md5sumfile]
    # check if the file $databasename.database_info.txt is locally readable. 
    if {[file readable $file_on_disk]} {
	set result [catch {set fp [open $file_on_disk r]} msg]
	set result [catch {set fsize [file size $file_on_disk]} msg]
	set line [read $fp $fsize]
	close $fp
	scan $line "%d %s %d %f %f\n" gamesLocal databasenameLocal sizeLocal\
	  sizeMBlocal sizeMBlocalCompressed
	puts "$gamesLocal $sizeLocal $databasenameLocal $sizeMBlocalCompressed"
    } {
	# Since the file could not be found, we put a silly
	# number for the number of games locally, to be -1. 
	puts "no file on disk found"
	set gamesLocal -1
    }

    # Now obtain from the remote server the same information - i.e. 
    #  i) Games in database ii) File size iii) File name
    set url "$baseurl/$dbinfofile"
    puts "url=$url"

    set result [catch {set token [::http::geturl $url -binary 0]} msg]
    if {$result != 0} {
	tk_messageBox -type ok -icon error -title\
	  [tr TitleProblemAccessingWebSite] -message\
	  "$url\n\n$msg\n\n[tr ProblemAccessingWebSite]\n\n[tr\
	  IfYouCantResolveError]"
	return
    }
    set status [http::status $token]
    set code [http::code $token]
    set ind [string first 200 $code]
    if {$ind == -1} {
	tk_messageBox -type ok -icon warning -title\
	  [tr TitleProblemAccessingWebSite] -message\
	  "$url\n\n$code\n\n[tr ProblemAccessingWebSite]"
	return
    }
    set line [http::data $token]
    scan $line "%d %s %d %f %f %d %d %d %d %d %d %s %s %s %s %s %s\n"\
      gamesRemote databasenameRemote sizeRemote sizeMBremote\
      sizeMBremoteCompressed GameFileLength IndexFileLength NameFileLength\
      NumberOfGameParts NumberOfIndexParts NumberOfNameParts MD5ofGameFile x\
      MD5ofIndexFile x2 MD5ofNameFile x2
    set MD5ofIndexFile [string tolower $MD5ofIndexFile]
    set MD5ofNameFile [ string tolower $MD5ofNameFile ]
    set MD5ofGameFile [ string tolower $MD5ofGameFile ]

    if {$gamesLocal != $gamesRemote && $gamesLocal != -1} {
	tk_messageBox -type ok -icon warning -title\
	  [tr TitleSizeMismatchForMegadatabase] -message\
	  "[tr SizeMismatchForMegadatabase1]\n\n[tr\
	  SizeMismatchForMegadatabase2] '$url'\n[tr\
	  SizeMismatchForMegadatabase3] '$databasenameRemote'\n\
	  [tr SizeMismatchForMegadatabase4] $gamesRemote\n\n[tr\
	  SizeMismatchForMegadatabase5] '$file_on_disk'\n[tr\
	  SizeMismatchForMegadatabase6] $gamesLocal\n[tr\
	  SizeMismatchForMegadatabase7] $databasenameLocal\n\n[tr\
	  IfYouCantResolveError]"
	return
    }
    # if the file was not found locally, write it to disk.
    if {$gamesLocal == -1} {
	set result [catch {set fileId [open $file_on_disk w]} msg]
	if {$result !=0} {
	    tk_messageBox -type ok -icon error -title [tr CanNotWriteFile]\
	      -message "[tr CanNotWriteFile] $file_on_disk\n\n[tr\
	      CanNotWriteFile2]\n\n$msg\n\n[tr IfYouCantResolveError]"
	    return
	}
	# send the data to the file -
	# failure to add '-nonewline' will result in an extra newline
	# at the end of the file
	puts -nonewline $fileId $line
	close $fileId
    }
    # Calculate the temporary space needed. It should be the size of all the\
      zip files, plus
    # twice the uncompressed size (ince for the database, and once for the 
    # parts of it. 
    set tempspace [expr {$sizeMBremoteCompressed + 2 * $sizeMBremote + 2}]

    # Convert the MB data to the nearest 1 MB - pointless showwing\
      323.433784334 MB
    set tempspace [format "%.0f" $tempspace]
    set sizeMBremoteCompressed [format "%.0f" $sizeMBremoteCompressed]
    set sizeMBremote [format "%.0f" $sizeMBremote]


    set answer [tk_messageBox -type okcancel -icon info -title\
      [tr TitleDownloadDatabaseNow] -message "[tr DownloadDatabaseName]\
      '$databasenameRemote'. [tr NumberOfGames] $gamesRemote\n\n[tr\
      SizeCompressed] $sizeMBremoteCompressed MB\n\n[tr SizeUncompressed]\
      $sizeMBremote MB\n\n[tr NeedTemporarySpace] $tempspace MB\n\n[tr\
      ThereoreYouNeedSpace] $tempspace MB [tr ThereoreYouNeedSpace2]\n\n[tr\
      ContinueWithDownloadQ]"]

    # let the user cancel the download if he/she wants to. 
    switch -- $answer {
    ok { }
    cancel {
	    return
	}
    }



    puts "$GameFileLength $IndexFileLength $NameFileLength $NumberOfGameParts\
      $NumberOfIndexParts $NumberOfNameParts"
    # check unzip can be found. 
    if {[catch {exec unzip} fid]} {
	tk_messageBox -type ok -icon error -title [tr TitleNeedUnzip]\
	  -message [tr NeedUnzip]
	return
    }

    # Check for md5 under the names of both md5 and md5um. 
    if {$::windowsOS} {
      set md5 [file join $::chessdbExeDir md5 ]
      set md5 [file nativename $md5]
    }
    if {[catch {exec md5 do-not-remove.txt } fid]} {
	if {[catch {exec md5sum do-not-remove.txt} fid]} {
        set md5prog ""
	} {
            # checksum program not found under name md5, but is under md5sum
	    set md5prog md5sum
	}
    } {
        # checksum program found under the name md5
	set md5prog md5
    }
    if { $md5prog == "" } { 
	tk_messageBox -type ok -icon warning -title [tr TitleNoMD5ProgFound ] -message "[tr NoMD5ProgFound1 ]\n\n[tr NoMD5ProgFound2 ]\n\n[tr NoMD5ProgFound3]"
 
    }

    # The database on the remote server is broken up into mutiple parts 
    # using the UNIX 'split' command. Hence a file GM will be broken 
    # into GMaa GMab GMac ..etc

    # set numbers in ASCII for 'a'
    set letter1 97
    set letter2 97

    # Check if the GAME file is present. If it's local and of 
    # the correct size, we can assume it is OK. 

    set CompleteGameFileName [file nativename [file join $dirname\
      $databasenameRemote.sg3]]
    set CompleteNameFileName [file nativename [file join $dirname\
      $databasenameRemote.sn3]]
    set CompleteIndexFileName [file nativename [file join $dirname\
      $databasenameRemote.si3]]

    puts "CompleteGameFileName = $CompleteGameFileName"
    puts "CompleteIndexFileName = $CompleteIndexFileName"
    puts "CompleteNameFileName = $CompleteNameFileName"

    set SizeOfLocalGameFile -2
    set SizeOfLocalIndexFile -2
    set SizeOfLocalNameFile -2
    catch {set SizeOfLocalGameFile [file size $CompleteGameFileName]}
    catch {set SizeOfLocalIndexFile [file size $CompleteIndexFileName]}
    catch {set SizeOfLocalNameFile [file size $CompleteNameFileName]}

    puts "SizeOfLocalGameFile = $SizeOfLocalGameFile"
    puts "SizeOfLocalIndexFile = $SizeOfLocalIndexFile"
    puts "SizeOfLocalNameFile = $SizeOfLocalNameFile"

    if {$SizeOfLocalGameFile == $GameFileLength && $SizeOfLocalIndexFile ==\
      $IndexFileLength && $SizeOfLocalNameFile == $NameFileLength} {
       if { $md5prog == "" } {
	tk_messageBox -type ok -icon info -title [tr TitleAllFilesPresent]\
	  -message "[tr AllFilesProbablyOK]\n\n$CompleteGameFileName:\
	  $SizeOfLocalGameFile ([tr bytes]\n$CompleteIndexFileName:\
	  $SizeOfLocalIndexFile [tr bytes]\n$CompleteNameFileName:\
	  $SizeOfLocalNameFile [tr bytes]\n\n[tr AllFilesProbablyOK2]"

	tk_messageBox -type ok -icon info -title [tr TitleAllFilesPresent]\
	  -message "[tr AllFilesProbablyOK3] [tr AllFilesProbablyOK4]\
	  [tr AllFilesProbablyOK5]\n\n$CompleteGameFileName:\
	  $MD5ofGameFile\n$CompleteIndexFileName:\
	  $MD5ofIndexFile\n$CompleteNameFileName: $MD5ofNameFile"
	return
         } else {





        # Since we have a working MD5
        # All 3 database files will be checked for integrety
        # First the game file.
        set md5g [lindex [ exec $md5prog $CompleteGameFileName ]  0]
        set md5i [lindex [ exec $md5prog $CompleteIndexFileName ]  0]
        set md5n [lindex [ exec $md5prog $CompleteNameFileName ]  0]

        set md5g [ string tolower $md5g ]
        set md5i [ string tolower $md5i ]
        set md5n [ string tolower $md5n ]

        if { $md5g != $MD5ofGameFile } {
	   tk_messageBox -title [tr TitlePossibleCorruptedFile] -message "[tr GameFileCorrupted] $CompleteGameFileName [tr FileCorrupted1] [tr ChecksumExpected] $MD5ofGameFile\n[tr ChecksumOfFile] $md5g"
        }
        if { $md5i != $MD5ofIndexFile } {
	   tk_messageBox -title [tr TitlePossibleCorruptedFile] -message "[tr IndexFileCorrupted] $CompleteIndexFileName [tr FileCorrupted1] [tr ChecksumExpected] $MD5ofIndexFile\n[tr ChecksumOfFile] $md5i"
        }
        if { $md5n != $MD5ofNameFile } {
	   tk_messageBox -title [tr TitlePossibleCorruptedFile] -message "[tr NameFileCorrupted] $CompleteNameFileName [tr FileCorrupted1] [tr ChecksumExpected] $MD5ofNameFile\n[tr ChecksumOfFile] $md5n"
        }
        if { $md5n == $MD5ofNameFile &&  $md5i == $MD5ofIndexFile &&  $md5g == $MD5ofGameFile } {
        tk_messageBox -title [tr TitleMD5rOK] -message "[tr MD5rOK1]\n\n[tr MD5rOK2]"
        return

        }
      }
    }
    if {$result == 1} {
	set SizeOfLocalGameFile -1
    }
    puts "size of name file = $SizeOfLocalNameFile"
    set dbversion 3

    # retrieve ALL med checksums - only the 3 final files are in the 
    # databaseinfo file

    set w .downloadDatabaseWin
    if {[winfo exists $w]} {
	destroy $w
	return
    }
    toplevel $w
    wm title $w "[tr TitleDownloadConsoleMessages]"
    wm minsize $w 10 10

    # Frame 1 (the only frame in fact)
    set downloadDatabaseConsole [frame $w.downloadDatabaseConsole\
      -borderwidth 2]
    set textarea [text $downloadDatabaseConsole.textarea -wrap word -bg white\
      -height 40 -width 60 -yscrollcommand\
      [list $downloadDatabaseConsole.yscroll set] -setgrid 1]
    set yscroll [scrollbar $downloadDatabaseConsole.yscroll -command\
      [list $textarea yview]]

    grid $textarea -sticky news
    grid $yscroll -column 1 -row 0 -sticky ns
    grid rowconfig $downloadDatabaseConsole 0 -weight 1
    grid columnconfig $downloadDatabaseConsole 0 -weight 1

    $downloadDatabaseConsole.textarea tag configure h1 -font "helvetica 16"\
      -underline on

    $downloadDatabaseConsole.textarea tag configure h2 -font "helvetica 13"\
      -justify "left" -underline on

    $downloadDatabaseConsole.textarea tag configure normal -font "helvetica 8"\
      -justify "left" -underline off
    $downloadDatabaseConsole.textarea tag configure fixed -font "courier 10"\
      -justify "left" -underline off

    pack $downloadDatabaseConsole -fill both -expand true

    # Frame 6 'buttons2'
    set buttons2 [frame $w.buttons2 -borderwidth 0]
    button $buttons2.close -text [tr CancelDownload] -command {
	set answer [tk_messageBox -title [tr TitleReallyQuitDownload]\
	  -message "[tr ReallyQuitDownload]\n\n[tr ReallyQuitDownload2]"\
	  -type yesno -icon question]
	switch -- $answer {
	yes {
		puts "now destroying windows "
		destroy .downloadDatabaseWin
		unbusyCursor .
		return
	    }
	no {}
	}
    }
    grid $buttons2.close -row 0 -column 1 -sticky e
    pack $buttons2 -side right -fill x -padx 0 -pady 2 -ipadx 0 -ipady 2
    if {[winfo exists $downloadDatabaseConsole.textarea]} {
	$downloadDatabaseConsole.textarea insert end "[tr DownloadLog]\n\n" h1
    } {
	puts "Windows closed, so no $downloadDatabaseConsole.textarea insert\
	  end"
    }


    busyCursor .
    set totalNumberOfParts [expr {$NumberOfGameParts + $NumberOfIndexParts +\
      $NumberOfNameParts}]
    set loopcounter 0
    for {set i 1} {$i <= 3} {incr i} {
	if {$i == 1} {
	    set LetterInFileName g
	    set result [catch {set SizeOfLocalXFile [file size\
	      $CompleteGameFileName]}]
	    if {$result == 1} {
		set SizeOfLocalXFile -1
	    }
	    set XFileLength $GameFileLength
	    set NumberOfXParts $NumberOfGameParts
	    set CompleteXFileName $CompleteGameFileName
	}\
	elseif {$i == 2} {
	    set LetterInFileName i
	    set result [catch {set SizeOfLocalXFile [file size\
	      $CompleteIndexFileName]}]
	    if {$result == 1} {
		set SizeOfLocalXFile -1
	    }
	    set XFileLength $IndexFileLength
	    set NumberOfXParts $NumberOfIndexParts
	    set CompleteXFileName $CompleteIndexFileName
	}\
	elseif {$i == 3} {
	    set LetterInFileName n
	    set result [catch {set SizeOfLocalXFile [file size\
	      $CompleteNameFileName]}]
	    if {$result == 1} {
		set SizeOfLocalXFile -1
	    }
	    set XFileLength $NameFileLength
	    set NumberOfXParts $NumberOfNameParts
	    set CompleteXFileName $CompleteNameFileName
	}
	puts "$CompleteXFileName has $NumberOfXParts parts"
	puts "SizeOfLocalXFile == $SizeOfLocalXFile XFileLength == $XFileLength"
	#$downloadDatabaseConsole.textarea insert end "$CompleteXFileName has\
	  $NumberOfXParts parts\n" fixed
	if {$SizeOfLocalXFile != $XFileLength || $NumberOfXParts == 1} {
	    file delete $CompleteXFileName
	    for {set g 1} {$g <=$NumberOfXParts} {incr g} {
		incr loopcounter
		if {[winfo exists $downloadDatabaseConsole.textarea]} {
		    $downloadDatabaseConsole.textarea insert end "Checking for\
		      part $loopcounter of $totalNumberOfParts\n" fixed
		} {
		    return
		}

		if {$g == 1} {
		    set letter1 97
		    set letter2 97
		}
		update idletasks
		update
		updateMenuStates
		updateTitle
		updateStatusBar
		updateBoard -pgn
		updateStatusBar
		update
		update idletasks
		set filetodownload\
		  [format\
		  $databasenameRemote.s$LetterInFileName$dbversion%c%c.zip\
		  $letter1 $letter2]
		set GameFilePartName\
		  [format $databasenameRemote.s$LetterInFileName$dbversion%c%c\
		  $letter1 $letter2]
		set GameFilePartName [file join $dirname $GameFilePartName]
		set result [catch {set gamefilesize [file size\
		  $GameFilePartName]}]
		if {$result == 1} {
		    set gamefilesize -1
		}
		puts "result =$result GameFilePartName=$GameFilePartName\
		  filetodownload=$filetodownload gamefilesize=$gamefilesize"
		incr letter2
		if {$letter2 == 123} {
		    set letter2 97
		    incr letter1
		}
		if {$gamefilesize != 8388608} {
		    set url $baseurl/$filetodownload
		    puts "need to retirieve $filetodownload from $url"
		    if {[winfo exists $downloadDatabaseConsole.textarea]} {
			$downloadDatabaseConsole.textarea insert end\
			  "$url will be retrieved\
			  ($loopcounter/$totalNumberOfParts)\n" fixed
		    } {
			return
		    }
		    set file_on_disk [file join $dirname $filetodownload]
		    set file_on_disk [file nativename $file_on_disk]
		    #### ORIG set result [catch {set token\
		      [::http::geturl $url -binary 1]} msg]
		    #### TWIC set token [httpcopy $url [file join\
		      $::chessdbTWICDir $zipfile]]
		    set result [catch {set fileId [open $file_on_disk w]} msg]
		    if {$result !=0} {
			tk_messageBox -type ok -icon error -title\
			  [tr CanNotWriteFile] -message "[tr CanNotWriteFile]\
			  $file_on_disk\n\n[tr\
			  CanNotWriteFile2]\n\n$msg\n\n[tr\
			  IfYouCantResolveError]"
			unbusyCursor .
			return
		    }
		    close $fileId

		    set token [httpcopy $url $file_on_disk]
		    if {[catch {set status [http::status $token]} errmsg]} {
			tk_messageBox -type ok -icon error -title\
			  [tr TitleProblemAccessingWebSite]\
			  -message\
			  "$url\n\n$errmsg\n\n[tr\
			  ProblemAccessingWebSite]\n\n[tr\
			  IfYouCantResolveError]"
			unbusyCursor .
			return
		    }
		    puts $url
		    set code [http::code $token]
		    set ind [string first 200 $code]
		    if {$ind == -1} {
			tk_messageBox -type ok -icon warning -title\
			  [tr TitleProblemAccessingWebSite]\
			  -message\
			  "$url\n\n$code\n\n[tr ProblemAccessingWebSite]"
			return
		    }
		    if {[catch {exec unzip -o -d $dirname $file_on_disk}\
		      errmsg]} {
			tk_messageBox -type ok -icon error -title\
			  [tr TitleUnzipFailed] -message "[tr UnzipFailed]\
			  $file_on_disk [tr UnzipFailed2]\n\n$errmsg\n\n[tr\
			  IfYouCantResolveError]"
			unbusyCursor .
			return
		    }
                    
		} {
		    if {[winfo exists $downloadDatabaseConsole.textarea]} {
			$downloadDatabaseConsole.textarea insert end\
			  "$GameFilePartName already on disk.\n" fixed
		    } {
			return
		    }

		}
		# Open the uncompressed part of the game file.
		puts "opening $GameFilePartName for reading"
		set fp_in [open $GameFilePartName r]
                set deletethese [ concat $deletethese $GameFilePartName $GameFilePartName.zip]

		# Leave the characters \n and \r untouched. Without 
		# this Tcl will treat them as end-of-line characters and 
		# mangle them during input and output.
		fconfigure $fp_in -translation binary
                # files are 8 MB, so read in >= 8 MB. 
		set data [read $fp_in 9000000]
		close $fp_in
		# Now write it out to the 
		# $downloadDatabaseConsole.textarea insert end "Appending the\
		  part $GameFilePartName to  $CompleteXFileName" fixed
		set fp_out [open $CompleteXFileName a]
		fconfigure $fp_out -translation binary
		puts -nonewline $fp_out $data
		close $fp_out
		#$downloadDatabaseConsole.textarea insert end\
		  "Closing $CompleteXFileName\n" fixed 
	    }
	} { }
    }
    set aa sg3aa
    set ab sg3ab
    set ac sg3ac
    set az sg3az
    set ba sg3ba
    set bb sg3bb
    set bc sg3bc
    # changed $databasenameLocal to $databasenameRemote on the next 
    # tk_messageBox line, since although local will be the same as remote
     # if the database info files exists, if the file does not exist (i.e. 
    # directory used for first time, then the variable will be undefined
#    tk_messageBox -type ok -icon info -title [tr TitleDownloadComplete]\
      -message "[tr DownloadOfDatabaseComplete] $databasenameRemote \
      [tr DownloadOfDatabaseComplete2] '$dirname'\n\n[tr EnjoyYourDatabase]"




        # Since we have a working MD5
        # All 3 database files will be checked for integrety
        # First the game file.
        set md5g [lindex [ exec $md5prog $CompleteGameFileName ]  0]
        set md5i [lindex [ exec $md5prog $CompleteIndexFileName ]  0]
        set md5n [lindex [ exec $md5prog $CompleteNameFileName ]  0]

        set md5g [ string tolower $md5g]
        set md5i [ string tolower $md5i]
        set md5n [ string tolower $md5n]
        if { $md5g != $MD5ofGameFile } {
	   tk_messageBox -title [tr TitlePossibleCorruptedFile] -message "[tr GameFileCorrupted] $CompleteGameFileName [tr FileCorrupted1] [tr ChecksumExpected] $MD5ofGameFile\n[tr ChecksumOfFile] $md5g"
        return
        }
        if { $md5i != $MD5ofIndexFile } {
	   tk_messageBox -title [tr TitlePossibleCorruptedFile] -message "[tr IndexFileCorrupted] $CompleteIndexFileName [tr FileCorrupted1] [tr ChecksumExpected] $MD5ofIndexFile\n[tr ChecksumOfFile] $md5i"
        return
        }
        if { $md5n != $MD5ofNameFile } {
	   tk_messageBox -title [tr TitlePossibleCorruptedFile] -message "[tr NameFileCorrupted] $CompleteNameFileName [tr FileCorrupted1] [tr ChecksumExpected] $MD5ofNameFile\n[tr ChecksumOfFile] $md5n"
        return
        }
        if { $md5n == $MD5ofNameFile &&  $md5i == $MD5ofIndexFile &&  $md5g == $MD5ofGameFile } {
        tk_messageBox -title [tr TitleMD5rOK] -message "[tr MD5rOK1]\n\n[tr MD5rOK2]"
        $buttons2.close configure -text [tr Close] -command {
		destroy .downloadDatabaseWin
		unbusyCursor .
		return
        }
        }


    set answer [tk_messageBox -type okcancel -icon info -title\
      [tr TitelBigIntermediateFiles] -message\
      "[tr IntermediateFilesBig]\n\n[tr LetChessDBDelete]"]
    switch -- $answer {
    ok {
	    $downloadDatabaseConsole.textarea insert end "Unneeded parts will\
	      now be deleted\n" fixed
            # file delete $deletethese
            set sizefile "$databasename.sizes.txt"
            set sizefile [file join $dirname $sizefile]
            set sizefile [file nativename $sizefile ]
            set deletethese [ concat $deletethese $file_on_disk $sizefile]

            set dbfile "$databasename.database_info.txt"
            set dbfile [file join $dirname $dbfile]
            set dbfile [file nativename $dbfile ]
            set deletethese [ concat $deletethese $dbfile $sizefile]
            set pmax [ llength $deletethese]
            puts "pmax=$pmax"
            for {set p 0} {$p < $pmax} {incr p} {
               set filename [ lindex  $deletethese $p ]
               puts "filename = $filename"
               file delete $filename
            }
            # file delete $filename
	    unbusyCursor .
		destroy .downloadDatabaseWin
	    return
	}
    cancel {
	    tk_messageBox -type ok -icon info -title\
	      [tr TitleFilesRemainUndeleted] -message\
	      "[tr TheFilesWillNotBeDelete] \n\n$databasenameRemote.$aa.zip,\
	      $databasenameRemote.$ab.zip, $databasenameRemote.$ac.zip\
	      ...$databasenameRemote.$az.zip $databasenameRemote.$ba.zip\
	      $databasenameRemote.$bb.zip... \n\n[tr\
	      PlusUncompressedVersions]\n\n$databasenameRemote.$aa,\
	      $databasenameRemote.$ab, $databasenameRemote.$ac\
	      ...$databasenameRemote.$az $databasenameRemote.$ba\
	      $databasenameRemote.$bb..."
	    unbusyCursor .
	    return
	}
    }
}

